@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free oftware; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * callbacks_mainwindow.c - callbacks for the main window
@@ -47,7 +50,7 @@ extern GtkWidget *mainnotebook;
 extern GtkWidget *keyerwindow;
 extern preferencestype preferences;
 extern keyerstatetype keyerstate;
-extern statetype state;
+extern programstatetype programstate;
 extern GList *logwindowlist;
 extern GtkUIManager *ui_manager;
 
@@ -246,7 +249,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency + 50);
+			set_frequency (programstate.rigfrequency + 50);
 		}
 		else
 			return FALSE;
@@ -256,7 +259,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency - 50);
+			set_frequency (programstate.rigfrequency - 50);
 		}
 		else
 			return FALSE;
@@ -273,7 +276,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			{
 				if (preferences.polltime == 0)
 					get_frequency ();
-				set_frequency (state.rigfrequency + 50);
+				set_frequency (programstate.rigfrequency + 50);
 			}
 			else
 				return FALSE;
@@ -283,7 +286,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 			{
 				if (preferences.polltime == 0)
 					get_frequency ();
-				set_frequency (state.rigfrequency - 50);
+				set_frequency (programstate.rigfrequency - 50);
 			}
 			else
 				return FALSE;
