@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free oftware; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * callbacks_mainwindow_list.c - callbacks for the list widget
@@ -36,7 +39,6 @@
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *mainnotebook;
-extern statetype state;
 extern preferencestype preferences;
 extern GList *logwindowlist;
 
@@ -49,7 +51,7 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		*incheckbutton, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *framelabel, *awardsentry;
-	gchar *frametext, *entry;
+	gchar *frametext, *entry, *temp;
 	guint i, page, bandenum, modeenum;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -106,9 +108,25 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 
 		gtk_tree_model_get (model, &iter, DATE, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (dateentry), entry);
+
 		gtk_tree_model_get (model, &iter, GMT, &entry, -1);
+		if (strlen(entry) > 4)
+		{
+			temp = g_strndup (entry, 4);
+			gtk_entry_set_text (GTK_ENTRY (gmtentry), temp);
+			g_free (temp);
+		}
+		else
 		gtk_entry_set_text (GTK_ENTRY (gmtentry), entry);
+
 		gtk_tree_model_get (model, &iter, GMTEND, &entry, -1);
+		if (strlen(entry) > 4)
+		{
+			temp = g_strndup (entry, 4);
+			gtk_entry_set_text (GTK_ENTRY (endentry), temp);
+			g_free (temp);
+		}
+		else
 		gtk_entry_set_text (GTK_ENTRY (endentry), entry);
 
 		/* we don't need to convert to uppercase here */
