@@ -41,6 +41,7 @@
 #include "log.h"
 #include "hamlib-utils.h"
 #include "xlog_enum.h"
+#include "dxcc.h"
 
 #ifndef HAVE_STRPTIME
 #include "strptime.h"
@@ -51,6 +52,7 @@ extern GtkWidget *mainwindow, *keyerwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
 extern GList *logwindowlist;
+extern GtkUIManager *ui_manager;
 
 /* get the action name and use it to switch logs <alt>1, <alt>2, etc. */
 void 
@@ -189,6 +191,24 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 		datebutton = lookup_widget (mainwindow, "datebutton");
 		gtk_widget_grab_focus (datebutton);
 	}
+
+	/* Update (clear) Awards */
+
+	guint st, zone, cont, iota;
+	gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont, &iota);
+	if (result)
+	{
+		updatedxccframe (result, TRUE, st, zone, cont, iota);
+		g_free (result);
+	}
+	else
+	{
+		gchar *call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
+		updatedxccframe (call, FALSE, st, zone, cont, iota);
+		g_free (call);
+	}
+	g_free (aw);
 }
 
 /* click all buttons when hamlib enabled, fill in defaults */
@@ -348,6 +368,19 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_editable_set_position (GTK_EDITABLE(callentry), -1);
 }
 
+void
+on_addclickall_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	GtkWidget *clickallmenu, *abutton;
+
+	abutton = gtk_ui_manager_get_widget
+		(ui_manager, "/ToolBar/Add");
+	g_signal_emit_by_name (G_OBJECT (abutton), "clicked");
+	clickallmenu = gtk_ui_manager_get_widget
+		(ui_manager, "/MainMenu/EditMenu/Click All");
+	g_signal_emit_by_name (G_OBJECT (clickallmenu), "activate");
+}
+
 /* show/hide the toolbar */
 void
 on_view_toolbar_activate (GtkAction *action, gpointer user_data)
