@@ -281,7 +281,7 @@ void
 on_callentry_changed (GtkEditable * editable, gpointer user_data)
 {
 	gchar *call;
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 #if HAVE_SYS_SHM_H
 	gchar *errorstr;
 #endif
@@ -290,9 +290,9 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 
 	GtkWidget *awardsentry = lookup_widget (mainwindow, "awardsentry");
 	gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
-	gchar *result = valid_awards_entry (aw, &st, &zone, &cont);
+	gchar *result = valid_awards_entry (aw, &st, &zone, &cont, &iota);
 	if (!result)
-		updatedxccframe (call, FALSE, st, zone, cont);
+		updatedxccframe (call, FALSE, st, zone, cont, iota);
 	else
 		g_free (result);
 	g_free (aw);
@@ -328,20 +328,20 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 void
 on_awardsentry_changed (GtkEditable * editable, gpointer user_data)
 {
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 
 	gchar *aw = gtk_editable_get_chars (editable, 0, -1);
-	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont);
+	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont, &iota);
 	if (result)
 	{
-		updatedxccframe (result, TRUE, st, zone, cont);
+		updatedxccframe (result, TRUE, st, zone, cont, iota);
 		g_free (result);
 	}
 	else
 	{
 		GtkWidget *callentry = lookup_widget (mainwindow, "callentry");
 		gchar *call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
-		updatedxccframe (call, FALSE, st, zone, cont);
+		updatedxccframe (call, FALSE, st, zone, cont, iota);
 		g_free (call);
 	}
 	g_free (aw);
@@ -481,13 +481,32 @@ on_locatorentry_changed (GtkEditable * editable, gpointer user_data)
 	locator = gtk_editable_get_chars (GTK_EDITABLE (editable), 0, -1);
 	updatelocatorframe (locator);
 	g_free (locator);
+
+	/* Update Locator Award */
+
+	guint st, zone, cont, iota;
+	GtkWidget *awardsentry = lookup_widget (mainwindow, "awardsentry");
+	gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
+	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont, &iota);
+	if (result)
+	{
+		updatedxccframe (result, TRUE, st, zone, cont, iota);
+		g_free (result);
+	}
+	else
+	{
+		GtkWidget *callentry = lookup_widget (mainwindow, "callentry");
+		gchar *call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
+		updatedxccframe (call, FALSE, st, zone, cont, iota);
+		g_free (call);
+	}
+	g_free (aw);
 }
 
 void
 tv_changed (GtkTextBuffer *buffer, gpointer user_data)
 {
 	gint count;
-	GtkTextIter start, end;
 
 	count = gtk_text_buffer_get_char_count (buffer);
 	if (count > 512)
@@ -495,8 +514,6 @@ tv_changed (GtkTextBuffer *buffer, gpointer user_data)
 		update_statusbar (_("Warning, remarks line to long!!"));
 		gdk_beep ();
 	}
-	gtk_text_buffer_get_bounds (buffer, &start, &end);
-	gtk_text_buffer_apply_tag_by_name (buffer, "tiny", &start, &end);
 }
 
 /* entry get's focus because Alt+key is used */
