@@ -53,6 +53,10 @@ extern gushort dxcc_w[400][MAX_BANDS + 1];
 extern gushort dxcc_c[400][MAX_BANDS + 1];
 extern gushort wac_w[MAX_CONTINENTS][MAX_BANDS + 1];
 extern gushort wac_c[MAX_CONTINENTS][MAX_BANDS + 1];
+extern gushort was_w[MAX_STATES][MAX_BANDS + 1];
+extern gushort was_c[MAX_STATES][MAX_BANDS + 1];
+extern gushort waz_w[MAX_ZONES][MAX_BANDS + 1];
+extern gushort waz_c[MAX_ZONES][MAX_BANDS + 1];
 
 /* add a new qso to the log */
 void
@@ -70,7 +74,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTextIter start, end;
 	gchar *temp, *label;
 	gint bandindex, modeindex, i = 0, page, f, kms, l, result;
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
 	GtkTreeModel *model;
@@ -218,7 +222,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		{
 			if (strlen(qso[LOCATOR]) >= 2)
 			{
-				result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
+				result = locatordistance (preferences.locator, qso[LOCATOR], &kms, &l);
 				if (result == 0)
 				{
 					if (GTK_WIDGET_VISIBLE (unknown1hbox))
@@ -268,7 +272,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		if (GTK_WIDGET_VISIBLE(scorewindow))
 		{
 			/* update worked/confirmed array */
-			gchar *result = valid_awards_entry (qso[AWARDS], &st, &zone,  &cont);
+			gchar *result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont, &iota);
 			if (result)
 			{
 				lookup = lookupcountry_by_prefix (result);
@@ -280,15 +284,18 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			gboolean qslconfirmed = qslreceived (qso[QSLIN]);
 			if (preferences.scoringbands[f] == '1')
 			{
-				dxcc_w[lookup.country][f]++;
-				dxcc_w[lookup.country][MAX_BANDS]++;
-				if (qslconfirmed)
+				if (lookup.country > 0)
 				{
-					dxcc_c[lookup.country][f]++;
-					dxcc_c[lookup.country][MAX_BANDS]++;
+					dxcc_w[lookup.country][f]++;
+					dxcc_w[lookup.country][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						dxcc_c[lookup.country][f]++;
+						dxcc_c[lookup.country][MAX_BANDS]++;
+					}
+					if (dxcc_w[lookup.country][f] == 1 || dxcc_c[lookup.country][f] == 1)
+						update_dxccscoring ();
 				}
-				if (dxcc_w[lookup.country][f] == 1 || dxcc_c[lookup.country][f] == 1)
-					update_dxccscoring ();
 				if (cont != 99 || lookup.continent != 99)
 				{
 					if (cont == 99) cont = lookup.continent;
@@ -303,6 +310,47 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 						(wac_w[cont][f] == 1 || wac_c[cont][f] == 1))
 						update_wacscoring ();
 				}
+				if (st != 99)
+				{
+					was_w[st][f]++;
+					was_w[st][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						was_c[st][f]++;
+						was_c[st][MAX_BANDS]++;
+					}
+					if ((preferences.awardswas == 1) &&
+						(was_w[st][f] == 1 || was_c[st][f] == 1))
+						update_wasscoring ();
+				}
+				if ((zone > 0 && zone < 99) || (lookup.cq > 0 && lookup.cq < 99))
+				{
+					if (zone == 99) zone = lookup.cq;
+					waz_w[zone-1][f]++;
+					waz_w[zone-1][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						waz_c[zone-1][f]++;
+						waz_c[zone-1][MAX_BANDS]++;
+					}
+					if ((preferences.awardswaz == 1) &&
+						(waz_w[zone-1][f] == 1 || waz_c[zone-1][f] == 1))
+						update_wazscoring ();
+				}
+				if (iota != NOT_AN_IOTA)
+				{
+					iota_new_qso(iota, f, qslconfirmed);
+					/* TODO: update_iotascoring only upon w/c */
+					if ((preferences.awardsiota == 1))
+						update_iotascoring ();
+				}
+				if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+				{
+					loc_new_qso(qso[LOCATOR], f, qslconfirmed);
+					/* TODO: update_locscoring only upon w/c */
+					if ((preferences.awardsloc == 1))
+						update_locscoring ();
+				}
 			/* check if this is a new country and update scoring */
 			}
 		}
@@ -350,10 +398,10 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 		*nameentry, *qthentry, *unknownentry1, *unknownentry2,
 		*locatorentry, *incheckbutton, *outcheckbutton, *awardsentry;
 	GtkTextBuffer *b;
-	gchar *qsonumber, *label, *call, *freq, *awards, *temp;
+	gchar *qsonumber, *label, *call, *freq, *awards, *temp, *locator;
 	gboolean qslin;
 	gint i, page, f;
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 	logtype *logw;
 	GtkTreeIter selected, iter;
 	GtkTreeModel *model;
@@ -415,6 +463,8 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_editable_delete_text (GTK_EDITABLE (powerentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (nameentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (qthentry), 0, -1);
+
+			locator = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (locatorentry), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (unknownentry1), 0, -1);
 			gtk_editable_delete_text (GTK_EDITABLE (unknownentry2), 0, -1);
@@ -451,7 +501,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE(scorewindow))
 			{
 				/* update worked/confirmed array */
-				gchar *result = valid_awards_entry (awards,  &st, &zone,  &cont);
+				gchar *result = valid_awards_entry (awards, &st, &zone, &cont, &iota);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -463,17 +513,20 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 				f = freq2enum (freq);
 				if (preferences.scoringbands[f] == '1')
 				{
-					dxcc_w[lookup.country][f]--;
-					dxcc_w[lookup.country][MAX_BANDS]--;
-					if (qslin)
+					if (lookup.country > 0)
 					{
-						dxcc_c[lookup.country][f]--;
-						dxcc_c[lookup.country][MAX_BANDS]--;
-					}
+						dxcc_w[lookup.country][f]--;
+						dxcc_w[lookup.country][MAX_BANDS]--;
+						if (qslin)
+						{
+							dxcc_c[lookup.country][f]--;
+							dxcc_c[lookup.country][MAX_BANDS]--;
+						}
 		/* check if this is the only country on this frequency */
-					if (dxcc_w[lookup.country][f] == 0 ||
-						dxcc_c[lookup.country][f] == 0)
-						update_dxccscoring ();
+						if (dxcc_w[lookup.country][f] == 0 ||
+							dxcc_c[lookup.country][f] == 0)
+							update_dxccscoring ();
+					}
 					if (cont != 99 || lookup.continent != 99)
 					{
 						if (cont == 99) cont = lookup.continent;
@@ -488,6 +541,47 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 							(wac_w[cont][f] == 0 || wac_c[cont][f] == 0))
 							update_wacscoring ();
 					}
+					if (st != 99)
+					{
+						was_w[st][f]--;
+						was_w[st][MAX_BANDS]--;
+						if (qslin)
+						{
+							was_c[st][f]--;
+							was_c[st][MAX_BANDS]--;
+						}
+						if ((preferences.awardswas == 1) &&
+							(was_w[st][f] == 0 || was_c[st][f] == 0))
+							update_wasscoring ();
+					}
+					if ((zone > 0 && zone < 99) || (lookup.cq > 0 && lookup.cq < 99))
+					{
+						if (zone == 99) zone = lookup.cq;
+						waz_w[zone-1][f]--;
+						waz_w[zone-1][MAX_BANDS]--;
+						if (qslin)
+						{
+							waz_c[zone-1][f]--;
+							waz_c[zone-1][MAX_BANDS]--;
+						}
+						if ((preferences.awardswaz == 1) &&
+							(waz_w[zone-1][f] == 0 || waz_c[zone-1][f] == 0))
+							update_wazscoring ();
+					}
+					if (iota != NOT_AN_IOTA)
+					{
+						iota_del_qso(iota, f, qslin);
+						/* TODO: update_iotascoring only upon w/c */
+						if ((preferences.awardsiota == 1))
+							update_iotascoring ();
+					}
+					if (locator && (strlen(locator) > 0))
+					{
+						loc_del_qso(locator, f, qslin);
+						/* TODO: update_locscoring only upon w/c */
+						if ((preferences.awardsloc == 1))
+							update_locscoring ();
+					}
 				}
 			}
 			if (preferences.saving == 2)
@@ -499,6 +593,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 		g_free (freq);
 		g_free (awards);
 		g_free (temp);
+		g_free (locator);
 		}
 	}
 }
@@ -519,7 +614,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
 	gint bandindex, modeindex, i = 0, page, fr, froption, result, kms, l;
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards, *logtime, *logendtime;
 	logtype *logw;
 	GtkTreeIter selected;
@@ -700,7 +795,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			{
 				if (strlen(qso[LOCATOR]) >= 2)
 				{
-					result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
+					result = locatordistance (preferences.locator, qso[LOCATOR], &kms, &l);
 					if (result == 0)
 					{
 						if (GTK_WIDGET_VISIBLE (unknown1hbox))
@@ -746,7 +841,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 			if (GTK_WIDGET_VISIBLE(scorewindow))
 			{ /* first we delete, then we add */
-				gchar *result = valid_awards_entry (logawards, &st, &zone, &cont);
+				gchar *result = valid_awards_entry (logawards, &st, &zone, &cont, &iota);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -759,13 +854,15 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				qslconfirmed = qslreceived (logqslin);
 				if (preferences.scoringbands[fr] == '1')
 				{
-
-					dxcc_w[lookup.country][fr]--;
-					dxcc_w[lookup.country][MAX_BANDS]--;
-					if (qslconfirmed)
+					if (lookup.country > 0)
 					{
-						dxcc_c[lookup.country][fr]--;
-						dxcc_c[lookup.country][MAX_BANDS]--;
+						dxcc_w[lookup.country][fr]--;
+						dxcc_w[lookup.country][MAX_BANDS]--;
+						if (qslconfirmed)
+						{
+							dxcc_c[lookup.country][fr]--;
+							dxcc_c[lookup.country][MAX_BANDS]--;
+						}
 					}
 					if (cont != 99 || lookup.continent != 99)
 					{
@@ -778,9 +875,34 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 							wac_c[cont][MAX_BANDS]--;
 						}
 					}
+					if (st != 99)
+					{
+						was_w[st][fr]--;
+						was_w[st][MAX_BANDS]--;
+						if (qslconfirmed)
+						{
+							was_c[st][fr]--;
+							was_c[st][MAX_BANDS]--;
+						}
+					}
+					if ((zone > 0 && zone < 99) || (lookup.cq > 0 && lookup.cq < 99))
+					{
+						if (zone == 99) zone = lookup.cq;
+						waz_w[zone-1][fr]--;
+						waz_w[zone-1][MAX_BANDS]--;
+						if (qslconfirmed)
+						{
+							waz_c[zone-1][fr]--;
+							waz_c[zone-1][MAX_BANDS]--;
+						}
+					}
+					if (iota != NOT_AN_IOTA)
+						iota_del_qso(iota, fr, qslconfirmed);
+					if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+						loc_del_qso(qso[LOCATOR], fr, qslconfirmed);
 				}
 
-				result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont);
+				result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont, &iota);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -793,13 +915,15 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				qslconfirmed = qslreceived (qso[QSLIN]);
 				if (preferences.scoringbands[fr] == '1')
 				{
-
-					dxcc_w[lookup.country][fr]++;
-					dxcc_w[lookup.country][MAX_BANDS]++;
-					if (qslconfirmed)
+					if (lookup.country > 0)
 					{
-						dxcc_c[lookup.country][fr]++;
-						dxcc_c[lookup.country][MAX_BANDS]++;
+						dxcc_w[lookup.country][fr]++;
+						dxcc_w[lookup.country][MAX_BANDS]++;
+						if (qslconfirmed)
+						{
+							dxcc_c[lookup.country][fr]++;
+							dxcc_c[lookup.country][MAX_BANDS]++;
+						}
 					}
 					if (cont != 99 || lookup.continent != 99)
 					{
@@ -812,11 +936,40 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 							wac_c[cont][MAX_BANDS]++;
 						}
 					}
+					if (st != 99)
+					{
+						was_w[st][fr]++;
+						was_w[st][MAX_BANDS]++;
+						if (qslconfirmed)
+						{
+							was_c[st][fr]++;
+							was_c[st][MAX_BANDS]++;
+						}
+					}
+					if ((zone > 0 && zone < 99) || (lookup.cq > 0 && lookup.cq < 99))
+					{
+						if (zone == 99) zone = lookup.cq;
+						waz_w[zone-1][fr]++;
+						waz_w[zone-1][MAX_BANDS]++;
+						if (qslconfirmed)
+						{
+							waz_c[zone-1][fr]++;
+							waz_c[zone-1][MAX_BANDS]++;
+						}
+					}
+					if (iota != NOT_AN_IOTA)
+						iota_new_qso(iota, fr, qslconfirmed);
+					if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+						loc_new_qso(qso[LOCATOR], fr, qslconfirmed);
 				}
 				/* don't bother if this is a new one or if a
 					country is deleted, just update scoring */
 				update_dxccscoring ();
 				if (preferences.awardswac == 1) update_wacscoring ();
+				if (preferences.awardswas == 1) update_wasscoring ();
+				if (preferences.awardswaz == 1) update_wazscoring ();
+				if (preferences.awardsiota == 1) update_iotascoring ();
+				if (preferences.awardsloc == 1) update_locscoring ();
 			}
 
 			g_free (logcall);
