@@ -55,6 +55,10 @@ gushort wac_w[MAX_CONTINENTS][MAX_BANDS + 1];
 gushort wac_c[MAX_CONTINENTS][MAX_BANDS + 1];
 gushort was_w[MAX_STATES][MAX_BANDS + 1];
 gushort was_c[MAX_STATES][MAX_BANDS + 1];
+GHashTable *iota_w[MAX_BANDS + 1];
+GHashTable *iota_c[MAX_BANDS + 1];
+GHashTable *loc_w[MAX_BANDS + 1];
+GHashTable *loc_c[MAX_BANDS + 1];
 
 /* free memory used by the dxcc array */
 void
@@ -76,6 +80,14 @@ cleanup_dxcc (void)
 		g_ptr_array_free (dxcc, TRUE);
 	}
 	if (prefixes) g_hash_table_destroy (prefixes);
+
+	for (i = 0; i < MAX_BANDS; i++)
+	{
+		if (iota_w[i]) g_hash_table_destroy (iota_w[i]);
+		if (iota_c[i]) g_hash_table_destroy (iota_c[i]);
+		if (loc_w[i]) g_hash_table_destroy (loc_w[i]);
+		if (loc_c[i]) g_hash_table_destroy (loc_c[i]);
+	}
 }
 
 /* free memory used by the area array */
@@ -364,11 +376,10 @@ readctydata (void)
 	}
 
 	dxcc = g_ptr_array_new ();
-	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal,
-		(GDestroyNotify)g_free, NULL);
+	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
 	/* first field in case hash_table_lookup returns NULL */
-	dxcc_add ("Unknown", 0, 0, 0, 0, 0, 0, "", "");
+	dxcc_add ("Unknown", 0, 0, 99, 0, 0, 0, "", "");
 	programstate.countries = 1;
 
 	while (!feof (fp))
@@ -504,7 +515,7 @@ gchar lookuparea (gchar *callsign)
 
 /* update information of the DXCC frame with the current callsign */
 void
-updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont)
+updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont, guint iota)
 {
 	GtkWidget *dxcclabel1, *dxcclabel3, *dxcclabel4, *contlabel, *itulabel,
 		*cqlabel, *dxcclabel5, *dxccframe, *framelabel, *countrytreeview;
@@ -513,9 +524,9 @@ updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont)
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	struct info lookup;
+	gchar iter_num[2] = "0";
 	gint j;
-
-	if (strlen (item) == 0) return;
+	gdouble lat, lon;
 
 	dxcclabel1 = lookup_widget (scorewindow, "dxcclabel1");
 	dxcclabel3 = lookup_widget (scorewindow, "dxcclabel3");
@@ -550,36 +561,162 @@ updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont)
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
 
 	/* update DXCC */
-	gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string ("0"));
 	dxcc_data *d = g_ptr_array_index (dxcc, lookup.country);
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, d->px, -1);
-	for (j = 0; j < MAX_BANDS; j++)
+	if (lookup.country != 0)
 	{
-		if (dxcc_w[lookup.country][j] > 0)
-			temp = g_strdup_printf ("%d", dxcc_w[lookup.country][j]);
-		else
-			temp = (dxcc_c[lookup.country][j] > 0) ? "0" : "";
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, d->px, -1);
+		iter_num[0]++;
+		for (j = 0; j < MAX_BANDS; j++)
+		{
+			if (dxcc_c[lookup.country][j] > 0)
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+			else if (dxcc_w[lookup.country][j] > 0)
+			{
+				temp = g_strdup_printf ("%d", dxcc_w[lookup.country][j]);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
+			}
+			else
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+		}
 	}
 
 	/* update WAC */
-	if (preferences.awardswac == 1)
+	if (preferences.awardswac == 1 && lookup.country != 0)
 	{
-		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string ("1"));
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+		iter_num[0]++;
 		temp = g_strdup_printf ("WAC-%s", enum_to_cont (lookup.continent));
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, temp, -1);
 		for (j = 0; j < MAX_BANDS; j++)
 		{
-			if (wac_w[lookup.continent][j] > 0)
+			if (wac_c[lookup.continent][j] > 0)
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+			else if (wac_w[lookup.continent][j] > 0)
 			{
 				temp = g_strdup_printf ("%d", wac_w[lookup.continent][j]);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
 			}
 			else
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+		}
+	}
+
+	/* update WAS */
+	if (preferences.awardswas == 1 && st != 99)
+	{
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+
+		temp = g_strdup_printf ("WAS-%s", enum_to_state (st));
+		iter_num[0]++;
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, temp, -1);
+		for (j = 0; j < MAX_BANDS; j++)
 		{
-				temp = (wac_c[lookup.continent][j] > 0) ? "0" : "";
+			if (was_c[st][j] > 0)
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+			else if (was_w[st][j] > 0)
+			{
+				temp = g_strdup_printf ("%d", was_w[st][j]);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
 			}
+			else
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+		}
+	}
+
+	/* update WAZ */
+	if (preferences.awardswaz == 1 && lookup.cq != 0)
+	{
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+		iter_num[0]++;
+		temp = g_strdup_printf ("WAZ-%d", lookup.cq);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, temp, -1);
+		for (j = 0; j < MAX_BANDS; j++)
+		{
+			if (waz_c[lookup.cq-1][j] > 0)
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+			else if (waz_w[lookup.cq-1][j] > 0)
+			{
+				temp = g_strdup_printf ("%d", waz_w[lookup.cq-1][j]);
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
+			}
+			else
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+		}
+	}
+
+	/* update IOTA */
+	if (preferences.awardsiota == 1 && iota != NOT_AN_IOTA)
+	{
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+
+		gchar *iotastr = num_to_iota(iota);
+		iter_num[0]++;
+
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, iotastr, -1);
+		for (j = 0; j < MAX_BANDS; j++)
+		{
+				gpointer p_iota_w = g_hash_table_lookup (iota_w[j], iotastr);
+				gpointer p_iota_c = g_hash_table_lookup (iota_c[j], iotastr);
+
+				if (p_iota_c && GPOINTER_TO_INT(p_iota_c) > 0)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+				else if (p_iota_w && GPOINTER_TO_INT(p_iota_w) > 0)
+				{
+					temp = g_strdup_printf ("%d", GPOINTER_TO_INT(p_iota_w));
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
+				}
+				else
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+		}
+		g_free(iotastr);
+	}
+
+	/* update Grid Locator */
+	if (preferences.awardsloc == 1)
+	{
+		GtkWidget *locatorentry = lookup_widget (mainwindow, "locatorentry");
+		gchar *locator = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+		gchar *loc4 = loc_norm(locator);
+		g_free (locator);
+
+		if (loc4)
+		{
+			temp = g_strdup_printf ("%s", loc4);
+			iter_num[0]++;
+
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, temp, -1);
+			for (j = 0; j < MAX_BANDS; j++)
+			{
+				gpointer p_loc_w = g_hash_table_lookup (loc_w[j], loc4);
+				gpointer p_loc_c = g_hash_table_lookup (loc_c[j], loc4);
+
+				if (p_loc_c && GPOINTER_TO_INT(p_loc_c) > 0)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "0", -1);
+				else if (p_loc_w && GPOINTER_TO_INT(p_loc_w) > 0)
+				{
+					temp = g_strdup_printf ("%d", GPOINTER_TO_INT(p_loc_w));
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
+				}
+				else
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, "", -1);
+			}
+			g_free(loc4);
+		}
+	}
+
+	/* Clear the rest of iter_num's */
+	while (iter_num[0] < '0'+NB_AWARDS)
+	{
+		gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+		temp = g_strdup ("");
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, temp, -1);
+		for (j = 0; j < MAX_BANDS; j++)
+		{
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, j + 1, temp, -1);
 		}
+		iter_num[0]++;
 	}
 
 	if (g_strrstr(d->countryname, "&"))
@@ -621,11 +758,35 @@ updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont)
 	itutext = g_strdup_printf ("ITU %d", lookup.itu);
 	cqtext = g_strdup_printf ("CQ %d", lookup.cq);
 	labeltext3 = g_strdup_printf (_("Timezone: %+1.1f"), (gdouble)d->timezone/10);
-	labeltext4 = g_strdup_printf (_("Location: %+1.2f %+1.2f"),
+
+	if (d->latitude >= 0 && d->longitude >= 0)
+	labeltext4 = g_strdup_printf (_("Location: %1.2fN %1.2fW"),
 		(gdouble)d->latitude/100, (gdouble)d->longitude/100);
-	if (lookup.country > 0) gcresult = g_strdup_printf ("<small>%s</small>",
-		greatcircle (preferences.units, programstate.mylocation,
-		(gdouble)d->latitude/100, (gdouble)d->longitude/100));
+	else if (d->latitude >= 0 && d->longitude < 0)
+	labeltext4 = g_strdup_printf (_("Location: %1.2fN %1.2fE"),
+		(gdouble)d->latitude/100, -1 * (gdouble)d->longitude/100);
+	else if (d->latitude < 0 && d->longitude >= 0)
+	labeltext4 = g_strdup_printf (_("Location: %1.2fS %1.2fW"),
+		-1 * (gdouble)d->latitude/100, (gdouble)d->longitude/100);
+	else
+	labeltext4 = g_strdup_printf (_("Location: %1.2fS %1.2fE"),
+		-1 * (gdouble)d->latitude/100, -1 * (gdouble)d->longitude/100);
+	
+	if (lookup.country > 0)
+	{
+		if (preferences.NS == 0)
+			lat = -1.0 * preferences.latitude;
+		else
+			lat = preferences.latitude;
+		if (preferences.EW == 0)
+			lon = -1.0 * preferences.longitude;
+		else
+			lon = preferences.longitude;
+
+		gcresult = g_strdup_printf ("<small>%s</small>",
+		gcircle (preferences.units, lat, lon,
+			(gdouble)d->latitude/100, (gdouble)d->longitude/100));
+	}
 	gtk_label_set_markup (GTK_LABEL (dxcclabel1), labeltext1);
 	gtk_label_set_text (GTK_LABEL (contlabel), conttext);
 	gtk_label_set_text (GTK_LABEL (itulabel), itutext);
@@ -707,6 +868,269 @@ void update_wacscoring (void)
 	g_free (str);
 }
 
+void update_wasscoring (void)
+{
+	gint i, j, worked[MAX_BANDS + 1], confirmed[MAX_BANDS + 1];
+	GtkWidget *wastreeview;
+	GtkTreeModel *wasmodel;
+	GtkTreeIter wasiter;
+	gchar *str = g_strdup ("");;
+
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		worked[j] = 0;
+		confirmed[j] = 0;
+	}
+	for (i = 0; i < MAX_STATES; i++)
+	{
+		for (j = 0; j <= MAX_BANDS; j++)
+		{
+			if (was_w[i][j] != 0) worked[j]++;
+			if (was_c[i][j] != 0) confirmed[j]++;
+		}
+	}
+	wastreeview = lookup_widget (scorewindow, "wastreeview");
+	wasmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (wastreeview));
+	gtk_tree_model_get_iter (wasmodel, &wasiter, gtk_tree_path_new_from_string ("0"));
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		str = g_strdup_printf ("%d\n%d", worked[j], confirmed[j]);
+		gtk_list_store_set (GTK_LIST_STORE (wasmodel), &wasiter, j, str, -1);
+	}
+	g_free (str);
+}
+
+void update_wazscoring (void)
+{
+	gint i, j, worked[MAX_BANDS + 1], confirmed[MAX_BANDS + 1];
+	GtkWidget *waztreeview;
+	GtkTreeModel *wazmodel;
+	GtkTreeIter waziter;
+	gchar *str = g_strdup ("");;
+
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		worked[j] = 0;
+		confirmed[j] = 0;
+	}
+	for (i = 0; i < MAX_ZONES; i++)
+	{
+		for (j = 0; j <= MAX_BANDS; j++)
+		{
+			if (waz_w[i][j] != 0) worked[j]++;
+			if (waz_c[i][j] != 0) confirmed[j]++;
+		}
+	}
+	waztreeview = lookup_widget (scorewindow, "waztreeview");
+	wazmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (waztreeview));
+	gtk_tree_model_get_iter (wazmodel, &waziter, gtk_tree_path_new_from_string ("0"));
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		str = g_strdup_printf ("%d\n%d", worked[j], confirmed[j]);
+		gtk_list_store_set (GTK_LIST_STORE (wazmodel), &waziter, j, str, -1);
+	}
+	g_free (str);
+}
+
+void update_iotascoring (void)
+{
+	gint j, worked[MAX_BANDS + 1], confirmed[MAX_BANDS + 1];
+	GtkWidget *iotatreeview;
+	GtkTreeModel *iotamodel;
+	GtkTreeIter iotaiter;
+	gchar *str = g_strdup ("");;
+
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		worked[j] = 0;
+		confirmed[j] = 0;
+	}
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		worked[j] = g_hash_table_size(iota_w[j]);
+		confirmed[j] = g_hash_table_size(iota_c[j]);
+	}
+
+	iotatreeview = lookup_widget (scorewindow, "iotatreeview");
+	iotamodel = gtk_tree_view_get_model (GTK_TREE_VIEW (iotatreeview));
+	gtk_tree_model_get_iter (iotamodel, &iotaiter, gtk_tree_path_new_from_string ("0"));
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		str = g_strdup_printf ("%d\n%d", worked[j], confirmed[j]);
+		gtk_list_store_set (GTK_LIST_STORE (iotamodel), &iotaiter, j, str, -1);
+	}
+	g_free (str);
+}
+
+
+#if 0
+static void loc_gh_add (gpointer key, gpointer value, gpointer user_data)
+{
+	gint *p_counter = (gint *)user_data;
+
+	if (value && GPOINTER_TO_INT(value))
+		(*p_counter) ++;
+}
+#endif
+
+void update_locscoring (void)
+{
+	gint j, worked[MAX_BANDS + 1], confirmed[MAX_BANDS + 1];
+	GtkWidget *loctreeview;
+	GtkTreeModel *locmodel;
+	GtkTreeIter lociter;
+	gchar *str = g_strdup ("");;
+
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		worked[j] = 0;
+		confirmed[j] = 0;
+	}
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+#if 0
+		g_hash_table_foreach (loc_w[j], &loc_gh_add, (gpointer)&worked[j]);
+		g_hash_table_foreach (loc_c[j], &loc_gh_add, (gpointer)&confirmed[j]);
+#else
+		worked[j] = g_hash_table_size(loc_w[j]);
+		confirmed[j] = g_hash_table_size(loc_c[j]);
+#endif
+	}
+
+	loctreeview = lookup_widget (scorewindow, "loctreeview");
+	locmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (loctreeview));
+	gtk_tree_model_get_iter (locmodel, &lociter, gtk_tree_path_new_from_string ("0"));
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		str = g_strdup_printf ("%d\n%d", worked[j], confirmed[j]);
+		gtk_list_store_set (GTK_LIST_STORE (locmodel), &lociter, j, str, -1);
+	}
+	g_free (str);
+}
+
+void hash_inc(GHashTable *hash_table, const gchar *key)
+{
+	gpointer p, value;
+	p = g_hash_table_lookup (hash_table, key);
+	if (!p)
+		value = GINT_TO_POINTER (1);
+	else
+		value = GINT_TO_POINTER(GPOINTER_TO_INT(p) + 1);
+
+	g_hash_table_insert (hash_table, g_strdup(key), value);
+
+}
+
+void hash_dec(GHashTable *hash_table, const gchar *key)
+{
+	gpointer p, value;
+
+	p = g_hash_table_lookup (hash_table, key);
+	if (!p)
+		return;
+
+	value = GINT_TO_POINTER(GPOINTER_TO_INT(p) - 1);
+	if (value > 0)
+		g_hash_table_insert (hash_table, g_strdup(key), value);
+	else
+		g_hash_table_remove (hash_table, key);
+
+}
+
+gchar *loc_norm(const gchar *locator)
+{
+	gchar *loc4;
+
+	if (!locator || strlen(locator) < 4)
+		return NULL;
+
+	/* Make all locators uppercase - no dupe,
+	 * and keep only first 4 chars
+	 */
+	loc4 = g_ascii_strup(locator, -1);
+	loc4[4] = '\0';
+
+	return loc4;
+}
+
+void loc_new_qso(const gchar *locator, gint f, gboolean qslconfirmed)
+{
+	gchar *loc4;
+
+	loc4 = loc_norm(locator);
+	if (!loc4)
+		return;
+
+	hash_inc(loc_w[f], loc4);
+	hash_inc(loc_w[MAX_BANDS], loc4);
+
+	if (qslconfirmed)
+	{
+		hash_inc(loc_c[f], loc4);
+		hash_inc(loc_c[MAX_BANDS], loc4);
+	}
+
+	g_free(loc4);
+}
+
+void loc_del_qso(const gchar *locator, gint f, gboolean qslconfirmed)
+{
+	gchar loc4[5];
+
+	if (!locator || strlen(locator) < 4)
+		return;
+
+	memcpy(loc4, locator, 4);
+	loc4[4] = '\0';
+
+	hash_dec(loc_w[f], loc4);
+	hash_dec(loc_w[MAX_BANDS], loc4);
+
+	if (qslconfirmed)
+	{
+		hash_dec(loc_c[f], loc4);
+		hash_dec(loc_c[MAX_BANDS], loc4);
+	}
+}
+
+void iota_new_qso(guint iota, gint f, gboolean qslconfirmed)
+{
+	gchar *iotastr;
+
+	iotastr = num_to_iota(iota);
+	if (!iotastr)
+		return;
+
+	hash_inc(iota_w[f], iotastr);
+	hash_inc(iota_w[MAX_BANDS], iotastr);
+
+	if (qslconfirmed)
+	{
+		hash_inc(iota_c[f], iotastr);
+		hash_inc(iota_c[MAX_BANDS], iotastr);
+	}
+
+	g_free(iotastr);
+}
+
+void iota_del_qso(guint iota, gint f, gboolean qslconfirmed)
+{
+	gchar *iotastr;
+
+	iotastr = num_to_iota(iota);
+	if (!iotastr)
+		return;
+
+	hash_dec(iota_w[f], iotastr);
+	hash_dec(iota_w[MAX_BANDS], iotastr);
+
+	if (qslconfirmed)
+	{
+		hash_dec(iota_c[f], iotastr);
+		hash_dec(iota_c[MAX_BANDS], iotastr);
+	}
+}
+
 static void init_scoring (void)
 {
 	gint i, j;
@@ -723,17 +1147,39 @@ static void init_scoring (void)
 			wac_w[i][j] = 0;
 			wac_c[i][j] = 0;
 		}
+	for (i = 0; i < MAX_STATES; i++)
+		for (j = 0; j <= MAX_BANDS; j++)
+		{
+			was_w[i][j] = 0;
+			was_c[i][j] = 0;
+		}
+	for (i = 0; i < MAX_ZONES; i++)
+		for (j = 0; j <= MAX_BANDS; j++)
+		{
+			waz_w[i][j] = 0;
+			waz_c[i][j] = 0;
+		}
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		iota_w[j] = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+		iota_c[j] = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+	}
+	for (j = 0; j <= MAX_BANDS; j++)
+	{
+		loc_w[j] = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+		loc_c[j] = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+	}
 }
 
 void fill_scoring_arrays (void)
 {
 	gint i, f;
-	guint st, zone, cont;
+	guint st, zone, cont, iota;
 	gboolean valid, qslconfirmed;
 	logtype *logw;
 	GtkTreeModel *logmodel;
 	GtkTreeIter logiter;
-	gchar *call, *freq, *qslin, *awstr;
+	gchar *call, *freq, *qslin, *awstr, *locator;
 	struct info lookup;
 
 
@@ -749,8 +1195,9 @@ void fill_scoring_arrays (void)
 			gtk_tree_model_get (logmodel, &logiter, BAND, &freq, -1);
 			gtk_tree_model_get (logmodel, &logiter, QSLIN, &qslin, -1);
 			gtk_tree_model_get (logmodel, &logiter, AWARDS, &awstr, -1);
+			gtk_tree_model_get (logmodel, &logiter, LOCATOR, &locator, -1);
 			f = freq2enum (freq);
-			gchar *result = valid_awards_entry (awstr, &st, &zone, &cont);
+			gchar *result = valid_awards_entry (awstr, &st, &zone, &cont, &iota);
 			if (result)
 			{
 				lookup = lookupcountry_by_prefix (result);
@@ -783,6 +1230,35 @@ void fill_scoring_arrays (void)
 						wac_c[cont][MAX_BANDS]++;
 					}
 				}
+				if (st != 99)
+				{
+					was_w[st][f]++;
+					was_w[st][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						was_c[st][f]++;
+						was_c[st][MAX_BANDS]++;
+					}
+				}
+				if ((zone > 0 && zone < 99) || (lookup.cq > 0 && lookup.cq < 99))
+				{
+					if (zone == 99) zone = lookup.cq;
+					waz_w[zone-1][f]++;
+					waz_w[zone-1][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						waz_c[zone-1][f]++;
+						waz_c[zone-1][MAX_BANDS]++;
+					}
+				}
+				if (iota != NOT_AN_IOTA)
+				{
+					iota_new_qso(iota, f, qslconfirmed);
+				}
+				if (strlen(locator) > 0)
+				{
+					loc_new_qso(locator, f, qslconfirmed);
+				}
 			}
 			valid = gtk_tree_model_iter_next (logmodel, &logiter);
 		}
