@@ -23,6 +23,8 @@
 /*
  * dxcc.h
  */
+#ifndef DXCC_H
+#define DXCC_H
 
 /* struct for dxcc information from cty.dat */
 typedef struct
@@ -67,9 +69,23 @@ void cleanup_dxcc (void);
 void cleanup_area (void);
 gint readctydata (void);
 gint readareadata (void);
-void updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont);
+void updatedxccframe (gchar * item, gboolean byprefix, gint st, gint zone, gint cont, guint iota);
 void update_dxccscoring (void);
 void update_wacscoring (void);
+void update_wasscoring (void);
+void update_wazscoring (void);
+void update_iotascoring (void);
+void update_locscoring (void);
 void fill_scoring_arrays (void);
 struct info lookupcountry_by_callsign (gchar * callsign);
 struct info lookupcountry_by_prefix (gchar * px);
+
+void hash_inc(GHashTable *hash_table, const gchar *key);
+void hash_dec(GHashTable *hash_table, const gchar *key);
+void iota_new_qso(guint iota, gint f, gboolean qslconfirmed);
+void iota_del_qso(guint iota, gint f, gboolean qslconfirmed);
+void loc_new_qso(const gchar *locator, gint f, gboolean qslconfirmed);
+void loc_del_qso(const gchar *locator, gint f, gboolean qslconfirmed);
+gchar *loc_norm(const gchar *locator);
+
+#endif	/* DXCC_H */
