@@ -24,4 +24,4 @@
  * gc.h
  */
 
-gchar *greatcircle (gint units, gchar * qth, gdouble DEST_Lat, gdouble DEST_Long);
+gchar *gcircle (gint units, gdouble latmy, gdouble lonmy, gdouble latdx, gdouble londx);
