@@ -225,20 +225,17 @@ void on_awards_dxcc_activate (GtkMenuItem *menuitem, gpointer user_data)
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, d->px, -1);
 		for (j = 0; j < MAX_BANDS; j++)
 		{
-			if (dxcc_w[i][j] > 0)
+			if (dxcc_c[i][j] > 0)
+			{
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "0", -1);
+			}
+			else if (dxcc_w[i][j] > 0)
 			{
 				gchar *str = g_strdup_printf ("%d", dxcc_w[i][j]);
 				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, str, -1);
 				g_free (str);
 			}
 		}
-		for (j = 0; j < MAX_BANDS; j++)
-		{
-			if (dxcc_c[i][j] > 0)
-			{
-				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "0", -1);
-			}
-		}
 	}
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	gtk_widget_show_all (dialog);
