@@ -58,13 +58,14 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*bb1, *bb2, *bb3, *bb4, *bb5, *bb6, *bb7, *bb8, *bb9, *bb10,
 		*bb11, *bb12, *bb13, *bb14, *bb15, *bb16, *bb17, *bb18, *bb19,
 		*bb20, *bb21, *bb22, *bb23, *bb24, *bb25, *bb26, *bb27, *bb28,
-		*bb29, *vbox3, *bwac,
+		*bb29, *vbox3, *bwac, *bwas, *bwaz, *biota, *bloc,
 		*countrytreeview, *dxcctreeview;
 	gchar **states, **split, *scoringbands;
 	gboolean check;
 	GtkTreeViewColumn *column;
 	GtkTreeIter iter;
 	gint i, j, response;
+	gchar iter_num[2] = "1";
 
 	split = g_strsplit(preferences.b4columns2, ",", 0);
 	dialogsdialog = gtk_dialog_new_with_buttons (_("xlog - dialogs and windows"),
@@ -413,6 +414,18 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 	bwac = gtk_check_button_new_with_label ("WAC (Worked All Continents)");
 	gtk_box_pack_start (GTK_BOX (vbox3), bwac, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bwac), preferences.awardswac);
+	bwas = gtk_check_button_new_with_label ("WAS (Worked All States)");
+	gtk_box_pack_start (GTK_BOX (vbox3), bwas, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bwas), preferences.awardswas);
+	bwaz = gtk_check_button_new_with_label ("WAZ (Worked All Zones)");
+	gtk_box_pack_start (GTK_BOX (vbox3), bwaz, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bwaz), preferences.awardswaz);
+	biota = gtk_check_button_new_with_label ("IOTA (Islands On The Air)");
+	gtk_box_pack_start (GTK_BOX (vbox3), biota, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (biota), preferences.awardsiota);
+	bloc = gtk_check_button_new_with_label ("Grid Locators");
+	gtk_box_pack_start (GTK_BOX (vbox3), bloc, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bloc), preferences.awardsloc);
 
 	label = gtk_label_new (_("Worked Before"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
@@ -703,6 +716,7 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb29));
 		scoringbands[BAND_SUBMM] = check ? '1' : '0';
 
+		/* WAC */
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwac));
 		if (check)
 		{
@@ -725,13 +739,138 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow2));
 				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
 				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
-				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string ("1"));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+				iter_num[0]++;
 				for (j = 0; j < MAX_BANDS + 1; j++)
 					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
 			}
 			preferences.awardswac = 0;
 		}
 
+		/* WAS */
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwas));
+		if (check)
+		{
+			if (preferences.awardswas == 0)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				notebook_append_waspage (scorewindow, awardsnotebook);
+				fill_scoring_arrays ();
+				update_wasscoring ();
+			}
+			preferences.awardswas = 1;
+		}
+		else
+		{
+			if (preferences.awardswas == 1)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				GtkWidget *scrolledwindow3 = lookup_widget (scorewindow, "scrolledwindow3");
+				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow3));
+				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
+				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+				iter_num[0]++;
+				for (j = 0; j < MAX_BANDS + 1; j++)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+			}
+			preferences.awardswas = 0;
+		}
+
+		/* WAZ */
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwaz));
+		if (check)
+		{
+			if (preferences.awardswaz == 0)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				notebook_append_wazpage (scorewindow, awardsnotebook);
+				fill_scoring_arrays ();
+				update_wazscoring ();
+			}
+			preferences.awardswaz = 1;
+		}
+		else
+		{
+			if (preferences.awardswaz == 1)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				GtkWidget *scrolledwindow4 = lookup_widget (scorewindow, "scrolledwindow4");
+				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow4));
+				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
+				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+				iter_num[0]++;
+				for (j = 0; j < MAX_BANDS + 1; j++)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+			}
+			preferences.awardswaz = 0;
+		}
+
+		/* IOTA */
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(biota));
+		if (check)
+		{
+			if (preferences.awardsiota == 0)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				notebook_append_iotapage (scorewindow, awardsnotebook);
+				fill_scoring_arrays ();
+				update_iotascoring ();
+			}
+			preferences.awardsiota = 1;
+		}
+		else
+		{
+			if (preferences.awardsiota == 1)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				GtkWidget *scrolledwindow5 = lookup_widget (scorewindow, "scrolledwindow5");
+				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow5));
+				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
+				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+				iter_num[0]++;
+				for (j = 0; j < MAX_BANDS + 1; j++)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+			}
+			preferences.awardsiota = 0;
+		}
+
+		/* Grid locator */
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bloc));
+		if (check)
+		{
+			if (preferences.awardsloc == 0)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				notebook_append_locpage (scorewindow, awardsnotebook);
+				fill_scoring_arrays ();
+				update_locscoring ();
+			}
+			preferences.awardsloc = 1;
+		}
+		else
+		{
+			if (preferences.awardsloc == 1)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				GtkWidget *scrolledwindow6 = lookup_widget (scorewindow, "scrolledwindow6");
+				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow6));
+				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
+				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string (iter_num));
+				iter_num[0]++;
+				for (j = 0; j < MAX_BANDS + 1; j++)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+			}
+			preferences.awardsloc = 0;
+		}
+
 		countrytreeview = lookup_widget (scorewindow, "countrytreeview");
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_2190 + 1), scoringbands[BAND_2190] - 48);
