@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* gui_helpdialog.c - creation and destruction of the help dialog
  *
@@ -40,38 +43,16 @@
 
 extern GtkWidget *mainwindow;
 
-static GdkPixbuf *load_image (gchar *image)
-{
-	gchar *image_location, *msg;
-	GdkPixbuf *pixbuf = NULL;
-	GError *error = NULL;
-	
-	image_location = g_strconcat
-(XLOG_DATADIR, G_DIR_SEPARATOR_S, "images", G_DIR_SEPARATOR_S, image, NULL);
-	pixbuf = gdk_pixbuf_new_from_file (image_location, &error);
-	if (!pixbuf)
-	{
-		msg = g_strdup_printf (_("Failed to load pixbuf file: %s: %s\n"),
-			image_location, error->message);
-		update_statusbar (msg);
-		g_free (msg);
-		g_error_free (error);
-	}
-	g_free (image_location);
-	return (pixbuf);
-}
-
 static void open_help (gchar *filename)
 {
 	GtkWidget *helpdialog, *helptextview, *scrolledwindow, *ok_button;
-	gchar *buf, fbuf[80], *helpfile, *title, *p, *q;
+	gchar *buf, fbuf[80], *helpfile, *title;
 	const gchar *encoding;
 	FILE *in;
 	GtkTextBuffer *buffer;
 	GtkTextIter iter;
 	gint response, l;
 	GError *err;
-	GdkPixbuf *pix;
 	gsize utf8_len, read_len;
 	gboolean retry;
 
@@ -148,20 +129,6 @@ static void open_help (gchar *filename)
 				else if (buf[0] == '\t')
 					gtk_text_buffer_insert_with_tags_by_name
 						(buffer, &iter, buf, -1, "italic", NULL);
-				else if ((p = g_strrstr (buf , "{")))
-					{ /* insert an image with leading spaces */
-						*p = '\0';
-						l = strlen (buf);
-						if (l > 0)
-							gtk_text_buffer_insert (buffer, &iter, buf, -1);
-						*p = ' ';
-						pix = NULL;
-						q = g_strrstr (buf , "}");
-						if (q) *q = '\0';
-						pix = load_image (buf + l + 1);
-						if (pix)
-							gtk_text_buffer_insert_pixbuf (buffer, &iter, pix);
-					}
 				else
 					gtk_text_buffer_insert (buffer, &iter, buf, -1);
 			}
@@ -180,17 +147,13 @@ static void open_help (gchar *filename)
 	gtk_widget_destroy (helpdialog);
 }
 
-void
-on_helpfaq_activate (GtkMenuItem *menuitem,	gpointer user_data)
-{
-	open_help ("FAQ");
-}
-
-
 void
 on_helpmanual_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	open_help ("MANUAL");
+	gchar *command[] = {"xdg-open", NULL, NULL};
+	command[1] = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "manual", G_DIR_SEPARATOR_S, "index.html", NULL);
+	g_spawn_async (NULL, command, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
+	g_free (command[1]);
 }
 
 
@@ -200,12 +163,6 @@ on_helptodo_activate (GtkMenuItem *menuitem, gpointer user_data)
 	open_help ("TODO");
 }
 
-void
-on_helpthanks_activate (GtkMenuItem *menuitem, gpointer user_data)
-{
-	open_help ("THANKS");
-}
-
 void
 on_helpchangelog_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
