@@ -100,8 +100,7 @@ preview_update (GtkFileChooser *chooser, gpointer data)
 			if (fgets (buf, 80, in) == NULL) 
 				break;
 			else if (g_utf8_validate (buf, -1, NULL))
-				gtk_text_buffer_insert_with_tags_by_name 
-					(buffer, &start, buf, -1, "tiny", NULL);
+				gtk_text_buffer_insert (buffer, &start, buf, -1);
 		}
 	}
 	gtk_widget_set_size_request (previewscrolledwindow, 200, -1);
@@ -112,7 +111,6 @@ static void
 on_importlogbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *fileselection, *logentry, *preview;
-	GtkTextBuffer *buffer;
 	gchar *sellog;
 	gint response;
 
@@ -130,8 +128,6 @@ on_importlogbutton_clicked (GtkButton * button, gpointer user_data)
 	gtk_text_view_set_editable (GTK_TEXT_VIEW(preview), FALSE);
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW(preview), FALSE);
 	gtk_container_add (GTK_CONTAINER (previewscrolledwindow), preview);
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(preview));
-	gtk_text_buffer_create_tag (buffer, "tiny", "size", 8 * PANGO_SCALE, NULL);
 	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (fileselection),
 		previewscrolledwindow);
 	gtk_widget_set_size_request (previewscrolledwindow, 0, -1);
@@ -265,6 +261,14 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 					update_dxccscoring ();
 					if (preferences.awardswac == 1)
 						update_wacscoring ();
+					if (preferences.awardswas == 1)
+						update_wasscoring ();
+					if (preferences.awardswaz == 1)
+						update_wazscoring ();
+					if (preferences.awardsiota == 1)
+						update_iotascoring ();
+					if (preferences.awardsloc == 1)
+						update_locscoring ();
 				}
 
 				path = gtk_tree_path_new_from_string ("0");
