@@ -54,6 +54,9 @@
 #include "gui_tracedialog.h"
 #include "gui_awards_dxcc.h"
 #include "gui_awards_wac.h"
+#include "gui_awards_was.h"
+#include "gui_awards_waz.h"
+#include "gui_awards_iota.h"
 #include "support.h"
 #include "preferences.h"
 #include "gui_tracedialog.h"
@@ -160,6 +163,8 @@ static GtkActionEntry entries[] =
 		"Clear all fields", G_CALLBACK(on_clearframe_activate) },
   { "Click All", GTK_STOCK_APPLY, N_("Click All"), "<control>K",
 		"Click all buttons", G_CALLBACK(on_clickall_activate) },
+  { "Add and Click All", GTK_STOCK_ADD, N_("Add and Click All"), "<control><shift>A",
+		"Add a new QSO to the log and Click All", G_CALLBACK(on_addclickall_activate) },
   { "Delete", GTK_STOCK_REMOVE, N_("Delete"), "<control>D",
 		N_("Delete a selected log entry [Ctrl-D]"), G_CALLBACK(on_dbutton_clicked) },
   { "Find", GTK_STOCK_FIND, N_("Find"), "<control>F",
@@ -174,6 +179,9 @@ static GtkActionEntry entries[] =
   { "Awards", GTK_STOCK_INDEX, N_("Awards"), "", "Overview of Awards", NULL },
   { "DXCC", GTK_STOCK_INFO, "DXCC", "<control>1", "DXCC worked/confirmed", G_CALLBACK(on_awards_dxcc_activate) },
   { "WAC", GTK_STOCK_INFO, "WAC", "<control>2", "WAC worked/confirmed", G_CALLBACK(on_awards_wac_activate) },
+  { "WAS", GTK_STOCK_INFO, "WAS", "<control>3", "WAS worked/confirmed", G_CALLBACK(on_awards_was_activate) },
+  { "WAZ", GTK_STOCK_INFO, "WAZ", "<control>4", "WAZ worked/confirmed", G_CALLBACK(on_awards_waz_activate) },
+  { "IOTA", GTK_STOCK_INFO, "IOTA", "<control>5", "IOTA worked/confirmed", G_CALLBACK(on_awards_iota_activate) },
 
   { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "<control>L", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
   { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs and Windows"), "<control>B", "Settings for dialogs and windows used", G_CALLBACK(on_menu_dialogs_activate) },
@@ -234,6 +242,8 @@ static const char *ui_description =
 "		<separator name='sep4'/>"
 "		<menuitem action='Clear All'/>"
 "		<menuitem action='Click All'/>"
+"		<separator name='sep4a'/>"
+"		<menuitem action='Add and Click All'/>"
 "		<separator name='sep5'/>"
 "		<menuitem action='Find'/>"
 "	 </menu>"
@@ -252,6 +262,9 @@ static const char *ui_description =
 "		<menu action='Awards'>"
 "		  <menuitem action='DXCC'/>"
 "		  <menuitem action='WAC'/>"
+"		  <menuitem action='WAS'/>"
+"		  <menuitem action='WAZ'/>"
+"		  <menuitem action='IOTA'/>"
 "		</menu>"
 "	 </menu>"
 "	 <menu action='TabsMenu'>"
@@ -559,8 +572,6 @@ static const char *ui_description =
 	remtv = gtk_text_view_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL(remarkslabel), remtv);
 	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(remtv), GTK_WRAP_WORD);
-	b = gtk_text_view_get_buffer (GTK_TEXT_VIEW(remtv));
-	gtk_text_buffer_create_tag (b, "tiny", "size", 8 * PANGO_SCALE, NULL);
 	gtk_container_add (GTK_CONTAINER (remscr), remtv);
 
 	temp = g_strdup_printf ("<b>%s</b>", _("New QSO"));
@@ -623,6 +634,7 @@ static const char *ui_description =
 		G_CALLBACK (on_callentry_changed), NULL);
 	g_signal_connect ((gpointer) locatorentry, "changed",
 		G_CALLBACK (on_locatorentry_changed), NULL);
+	b = gtk_text_view_get_buffer (GTK_TEXT_VIEW(remtv));
 	g_signal_connect (G_OBJECT(b), "changed", G_CALLBACK (tv_changed), NULL);
 	g_signal_connect ((gpointer) awardsentry, "insert_text",
 		G_CALLBACK (on_awardsentry_insert_text), NULL);
