@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
@@ -32,7 +35,7 @@
 
 GtkWidget *keyerwindow = NULL;
 extern preferencestype preferences;
-extern statetype state;
+extern programstatetype programstate;
 extern GtkWidget *mainwindow;
 extern GtkUIManager *ui_manager;
 keyerstatetype keyerstate;
@@ -276,7 +279,7 @@ on_keyerwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency + 100);
+			set_frequency (programstate.rigfrequency + 50);
 			return TRUE;
 		}
 		else
@@ -287,7 +290,7 @@ on_keyerwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency - 100);
+			set_frequency (programstate.rigfrequency - 50);
 			return TRUE;
 		}
 		else
@@ -358,7 +361,6 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 	GtkObject *wpm_adj, *count_adj;
 	GdkPixbuf *keyer_icon_pixbuf;
 	GtkTextBuffer *buffer;
-	GtkTooltips *tooltips;
 	gint result = 0;
 	gchar *speed;
 	gboolean status;
@@ -374,7 +376,6 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 		gtk_window_set_icon (GTK_WINDOW (keyerwindow), keyer_icon_pixbuf);
 		g_object_unref (keyer_icon_pixbuf);
 	}
-	tooltips = gtk_tooltips_new ();
 
 	keyervbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (keyerwindow), keyervbox);
@@ -484,10 +485,10 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 	spentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (hbox8), spentry, TRUE, TRUE, 0);
 	gtk_widget_set_size_request (spentry, 120, -1);
-	gtk_tooltips_set_tip (tooltips, cqentry,
-		_("Auto exchange message in CQ mode"), NULL);
-	gtk_tooltips_set_tip (tooltips, spentry,
-		_("Auto exchange message in S&P mode"), NULL);
+	gtk_widget_set_tooltip_text
+		(cqentry, _("Auto exchange message in CQ mode"));
+	gtk_widget_set_tooltip_text
+		(spentry, _("Auto exchange message in S&P mode"));
 
 	hsep = gtk_hseparator_new ();
 	gtk_box_pack_start (GTK_BOX (keyervbox), hsep, TRUE, TRUE, 3);
@@ -530,6 +531,7 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 
 	keyertext = gtk_text_view_new ();
 	gtk_container_add (GTK_CONTAINER (scrolledkeyerwindow), keyertext);
+	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(keyertext), GTK_WRAP_CHAR);
 
 	gtk_entry_set_max_length (GTK_ENTRY (f1entry), 80);
 	gtk_entry_set_max_length (GTK_ENTRY (f2entry), 80);
