@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* gui_newlogdialog.c - creation and destruction of the newlog dialog 
  *
@@ -42,7 +45,7 @@ extern GList *logwindowlist;
 extern GtkWidget *mainnotebook;
 extern GtkWidget *mainwindow;
 extern preferencestype preferences;
-extern statetype state;
+extern programstatetype programstate;
 extern GtkUIManager *ui_manager;
 
 /* check for correct characters */
@@ -111,7 +114,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	gtk_widget_show_all (newlogdialog);
 	response = gtk_dialog_run (GTK_DIALOG (newlogdialog));
-	state.utf8error = FALSE;
+	programstate.utf8error = FALSE;
 	if (response == GTK_RESPONSE_OK)
 	{
 		entry = gtk_editable_get_chars (GTK_EDITABLE (newlogentry), 0, -1);
@@ -141,11 +144,11 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 					lp = log_file_open (filename, TYPE_FLOG);
 					if (lp)
 					{
-						logwindow =	openlogwindow (lp, entry, state.logwindows++);
+						logwindow =	openlogwindow (lp, entry, programstate.logwindows++);
 						log_file_qso_foreach (lp, fillin_list, logwindow);
 						log_file_close (lp);
 						logwindowlist =	g_list_append (logwindowlist, logwindow);
-						gtk_notebook_set_current_page(GTK_NOTEBOOK (mainnotebook), state.logwindows - 1);
+						gtk_notebook_set_current_page(GTK_NOTEBOOK (mainnotebook), programstate.logwindows - 1);
 						set_qsoframe (logwindow);
 						set_tabs_menu ();
 						xlogbackupfile =	g_strconcat (filename, ".backup", NULL);
@@ -163,11 +166,11 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 				lp = log_file_create (filename, TYPE_FLOG, qso_field_nr, qso_fields, qso_widths);
 				if (lp)
 				{
-					logwindow =	openlogwindow (lp, entry, state.logwindows++);
+					logwindow =	openlogwindow (lp, entry, programstate.logwindows++);
 					log_file_close (lp);
 					logwindow->filename = g_strdup (filename);
 					logwindowlist =	g_list_append (logwindowlist, logwindow);
-					gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
+					gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), programstate.logwindows - 1);
 					set_qsoframe (logwindow);
 					set_tabs_menu ();
 					set_font (preferences.logfont);
@@ -186,7 +189,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 		g_signal_emit_by_name (G_OBJECT (clearmenu), "activate");
 		gtk_widget_destroy (newlogdialog);
 
-		if (logexist && state.utf8error) 
+		if (logexist && programstate.utf8error) 
 			warningdialog (_("xlog - open log"), 
 				_("There were some errors converting from your locale to UTF8, "
 				"which is used by GTK+ internally. It is best if you start xlog "
