@@ -27,7 +27,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <math.h>
 #include <hamlib/rig.h>
+#include <hamlib/rotator.h>
 
 #include "gui_utils.h"
 #include "gui_fontselectiondialog.h"
@@ -45,6 +47,111 @@ extern preferencestype preferences;
 extern GtkWidget *mainwindow;
 extern programstatetype programstate;
 
+static void latlon_changed (GtkWidget *widget, gpointer data);
+
+static void
+qra_changed (GtkEntry *entry, gpointer data)
+{
+	gint retcode;
+	gdouble lat,lon;
+	gchar *temp;
+	GtkWidget *qthlocatorentry, *latentry, *longentry, *EWcombo, *NScombo;
+
+	qthlocatorentry = lookup_widget (preferencesdialog, "qthlocatorentry");
+	latentry = lookup_widget (preferencesdialog, "latentry");
+	longentry = lookup_widget (preferencesdialog, "longentry");
+	EWcombo = lookup_widget (preferencesdialog, "EWcombo");
+	NScombo = lookup_widget (preferencesdialog, "NScombo");
+
+	retcode = locator2longlat (&lon, &lat,
+		gtk_entry_get_text (GTK_ENTRY (qthlocatorentry)));
+
+	if (retcode == RIG_OK)
+	{
+
+		/* block signal emissions for lat/lon widgets */
+		g_signal_handlers_block_by_func
+			(GTK_OBJECT (latentry), latlon_changed, data);
+		g_signal_handlers_block_by_func
+			(GTK_OBJECT (longentry), latlon_changed, data);
+		g_signal_handlers_block_by_func
+			(GTK_OBJECT (EWcombo), latlon_changed, data);
+		g_signal_handlers_block_by_func
+			(GTK_OBJECT (NScombo), latlon_changed, data);
+
+		/* update widgets */
+		if (lat < 0.00)
+			gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 1);
+		else
+			gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 0);
+
+		if (lon < 0.00)
+			gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 1);
+		else
+			gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 0);
+
+		temp = g_strdup_printf ("%g", lat);
+		gtk_entry_set_text (GTK_ENTRY (latentry), temp);
+		temp = g_strdup_printf ("%g", lon);
+		gtk_entry_set_text (GTK_ENTRY (longentry), temp);
+
+		/* make sure text is upper case */
+		temp = g_ascii_strup (gtk_entry_get_text (GTK_ENTRY (qthlocatorentry)), -1);
+		gtk_entry_set_text (GTK_ENTRY (qthlocatorentry), temp);
+		g_free (temp);
+
+		/* unblock signal emissions */
+		g_signal_handlers_unblock_by_func
+			(GTK_OBJECT (latentry), latlon_changed, data);
+		g_signal_handlers_unblock_by_func
+			(GTK_OBJECT (longentry), latlon_changed, data);
+		g_signal_handlers_unblock_by_func
+			(GTK_OBJECT (EWcombo), latlon_changed, data);
+		g_signal_handlers_unblock_by_func
+			(GTK_OBJECT (NScombo), latlon_changed, data);
+	}
+
+}
+
+static void
+latlon_changed (GtkWidget *widget, gpointer data)
+{
+	gchar *locator;
+	gdouble lat, lon;
+	gint retcode;
+	GtkWidget *qthlocatorentry, *latentry, *longentry, *EWcombo, *NScombo;
+
+	locator = g_try_malloc (7);
+	qthlocatorentry = lookup_widget (preferencesdialog, "qthlocatorentry");
+	latentry = lookup_widget (preferencesdialog, "latentry");
+	longentry = lookup_widget (preferencesdialog, "longentry");
+	EWcombo = lookup_widget (preferencesdialog, "EWcombo");
+	NScombo = lookup_widget (preferencesdialog, "NScombo");
+	
+	lat = atof(gtk_editable_get_chars (GTK_EDITABLE (latentry), 0, -1));
+	lon = atof(gtk_editable_get_chars (GTK_EDITABLE (longentry), 0, -1));
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (NScombo)))
+	{
+		/* index 1 => South */
+		lat = -lat;
+	}
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (EWcombo)))
+	{
+		/* index 1 => West */
+		lon = -lon;
+	}
+
+	retcode = longlat2locator (lon, lat, locator, 3);
+	if (retcode == RIG_OK)
+	{
+		g_signal_handlers_block_by_func
+			(GTK_OBJECT (qthlocatorentry), qra_changed, data);
+		gtk_entry_set_text (GTK_ENTRY (qthlocatorentry), locator);
+		g_signal_handlers_unblock_by_func
+			(GTK_OBJECT (qthlocatorentry), qra_changed, data);
+	}
+}
+
 void
 on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -757,6 +864,18 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_connect ((gpointer) bandsradiobutton2, "toggled",
 		G_CALLBACK (on_bandsradiobutton_toggled), "2");
 
+	/* page 2 */
+	g_signal_connect (latentry, "changed", G_CALLBACK (latlon_changed), NULL);
+	g_signal_connect (longentry, "changed", G_CALLBACK (latlon_changed), NULL);
+	g_signal_connect (NScombo, "changed", G_CALLBACK (latlon_changed), NULL);
+	g_signal_connect (EWcombo, "changed", G_CALLBACK (latlon_changed), NULL);
+	g_signal_connect (qthlocatorentry, "changed", G_CALLBACK (qra_changed), NULL);
+	GLADE_HOOKUP_OBJECT (preferencesdialog, qthlocatorentry, "qthlocatorentry");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, latentry, "latentry");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, longentry, "longentry");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, NScombo, "NScombo");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, EWcombo, "EWcombo");
+
 	/* page 3, hamlib */
 	GLADE_HOOKUP_OBJECT (preferencesdialog, hamlibframe, "hamlibframe");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pollingframe, "pollingframe");
@@ -883,9 +1002,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		preferences.units = gtk_combo_box_get_active 
 			(GTK_COMBO_BOX (unitscombo))  == 1 ? 0 : 1;
 
-		programstate.mylocation = setlocation (preferences.latitude, preferences.NS,
-			preferences.longitude, preferences.EW);
-
 		/* get the comma seperated list of modes and assign 
 		 * to the optionmenu */
 		temp = gtk_editable_get_chars (GTK_EDITABLE (modesentry), 0, -1);
