@@ -30,6 +30,7 @@
 #include "gui_scorewindow.h"
 #include "xlog_enum.h"
 #include "dxcc.h"
+#include "awards_enum.h"
 
 extern GtkWidget *mainwindow;
 extern GtkUIManager *ui_manager;
@@ -51,19 +52,19 @@ on_scorewindow_delete_event (GtkWidget * widget, GdkEvent * event,	gpointer user
 }
 
 static void
-notebook_append_dxccpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, const gchar *treeviewname, const gchar *tabname, const gchar *windowname)
 {
-	GtkWidget *tablabel, *dxcctreeview, *scrolledwindow;
-	GtkListStore *dxccmodel;
+	GtkWidget *tablabel, *awardtreeview, *scrolledwindow;
+	GtkListStore *awardmodel;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
-	GtkTreeIter dxcciter;
+	GtkTreeIter awarditer;
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	/* one extra field for 'all' (bands) in last column */
-	dxccmodel = gtk_list_store_new (MAX_BANDS + 1,
+	awardmodel = gtk_list_store_new (MAX_BANDS + 1,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
@@ -72,417 +73,241 @@ notebook_append_dxccpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING);
-	dxcctreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(dxccmodel));
-	g_object_unref (G_OBJECT (dxccmodel));
-	gtk_container_add (GTK_CONTAINER (scrolledwindow), dxcctreeview);
+	awardtreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(awardmodel));
+	g_object_unref (G_OBJECT (awardmodel));
+	gtk_container_add (GTK_CONTAINER (scrolledwindow), awardtreeview);
 
 	renderer = gtk_cell_renderer_text_new ();
 
 	column = gtk_tree_view_column_new_with_attributes
 		("0.136", renderer, "text", BAND_2190, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2190] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_160] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_80] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5.2", renderer, "text", BAND_60, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_60] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_40] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_30] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_20] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_17] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_15] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_12] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_10] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_6] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_4] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_125CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("420", renderer, "text", BAND_70CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_70CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_33CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1240", renderer, "text", BAND_23CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_23CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("2300", renderer, "text", BAND_13CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_13CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3300", renderer, "text", BAND_9CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_9CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5650", renderer, "text", BAND_6CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_6CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10000", renderer, "text", BAND_3CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_3CM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24000", renderer, "text", BAND_12HMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_12HMM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("47000", renderer, "text", BAND_6MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_6MM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("75500", renderer, "text", BAND_4MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_4MM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("120000", renderer, "text", BAND_2HMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2HMM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("142000", renderer, "text", BAND_2MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2MM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("241000", renderer, "text", BAND_1MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_1MM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("300000", renderer, "text", BAND_SUBMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_SUBMM] - 48);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("All", renderer, "text", MAX_BANDS, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 
-	gtk_list_store_append (GTK_LIST_STORE (dxccmodel), &dxcciter);
+	gtk_list_store_append (GTK_LIST_STORE (awardmodel), &awarditer);
 	gtk_tree_selection_set_mode
-		(gtk_tree_view_get_selection (GTK_TREE_VIEW (dxcctreeview)),
+		(gtk_tree_view_get_selection (GTK_TREE_VIEW (awardtreeview)),
 		GTK_SELECTION_NONE );
-	tablabel = gtk_label_new ("DXCC");
+	tablabel = gtk_label_new (tabname);
 	gtk_notebook_append_page
 		(GTK_NOTEBOOK(awardsnotebook), scrolledwindow, tablabel);
 
-	GLADE_HOOKUP_OBJECT (scorewindow, dxcctreeview, "dxcctreeview");
+	GLADE_HOOKUP_OBJECT (scorewindow, awardtreeview, treeviewname);
+
+	if (windowname)
+	{
+		gtk_widget_show_all (scrolledwindow);
+		GLADE_HOOKUP_OBJECT (scorewindow, scrolledwindow, windowname);
+	}
+}
+
+static void
+notebook_append_dxccpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_append_awardpage (scorewindow, awardsnotebook, "dxcctreeview", "DXCC", NULL);
 }
 
 void
 notebook_append_wacpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
 {
-	GtkWidget *tablabel, *wactreeview, *scrolledwindow2;
-	GtkListStore *wacmodel;
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-	GtkTreeIter waciter;
+	notebook_append_awardpage (scorewindow, awardsnotebook, "wactreeview", "WAC", "scrolledwindow2");
+}
 
-	scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2),
-		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	wacmodel = gtk_list_store_new (MAX_BANDS + 1,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
-	wactreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(wacmodel));
-	g_object_unref (G_OBJECT (wacmodel));
-	gtk_container_add (GTK_CONTAINER (scrolledwindow2), wactreeview);
+void
+notebook_append_waspage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_append_awardpage (scorewindow, awardsnotebook, "wastreeview", "WAS", "scrolledwindow3");
+}
 
-	renderer = gtk_cell_renderer_text_new ();
+void
+notebook_append_wazpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_append_awardpage (scorewindow, awardsnotebook, "waztreeview", "WAZ", "scrolledwindow4");
+}
 
-	column = gtk_tree_view_column_new_with_attributes
-		("0.136", renderer, "text", BAND_2190, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2190] - 48);
+void
+notebook_append_iotapage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_append_awardpage (scorewindow, awardsnotebook, "iotatreeview", "IOTA", "scrolledwindow5");
+}
 
-	column = gtk_tree_view_column_new_with_attributes
-		("1.8", renderer, "text", BAND_160, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_160] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("3.5", renderer, "text", BAND_80, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_80] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("5.2", renderer, "text", BAND_60, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_60] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("7", renderer, "text", BAND_40, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_40] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("10", renderer, "text", BAND_30, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_30] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("14", renderer, "text", BAND_20, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_20] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("18", renderer, "text", BAND_17, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_17] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("21", renderer, "text", BAND_15, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_15] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("24", renderer, "text", BAND_12, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("28", renderer, "text", BAND_10, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_10] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("50", renderer, "text", BAND_6, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("70", renderer, "text", BAND_4, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("144", renderer, "text", BAND_2, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("222", renderer, "text", BAND_125CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_125CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("420", renderer, "text", BAND_70CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_70CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("902", renderer, "text", BAND_33CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_33CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("1240", renderer, "text", BAND_23CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_23CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("2300", renderer, "text", BAND_13CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_13CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("3300", renderer, "text", BAND_9CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_9CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("5650", renderer, "text", BAND_6CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("10000", renderer, "text", BAND_3CM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_3CM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("24000", renderer, "text", BAND_12HMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12HMM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("47000", renderer, "text", BAND_6MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6MM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("75500", renderer, "text", BAND_4MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4MM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("120000", renderer, "text", BAND_2HMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2HMM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("142000", renderer, "text", BAND_2MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2MM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("241000", renderer, "text", BAND_1MM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_1MM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("300000", renderer, "text", BAND_SUBMM, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_SUBMM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("All", renderer, "text", MAX_BANDS, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (wactreeview), column);
-
-	gtk_list_store_append (GTK_LIST_STORE (wacmodel), &waciter);
-	gtk_tree_selection_set_mode
-		(gtk_tree_view_get_selection (GTK_TREE_VIEW (wactreeview)),
-		GTK_SELECTION_NONE );
-	tablabel = gtk_label_new ("WAC");
-	gtk_notebook_append_page
-		(GTK_NOTEBOOK(awardsnotebook), scrolledwindow2, tablabel);
-
-	gtk_widget_show_all (scrolledwindow2);
-	GLADE_HOOKUP_OBJECT (scorewindow, wactreeview, "wactreeview");
-	GLADE_HOOKUP_OBJECT (scorewindow, scrolledwindow2, "scrolledwindow2");
+void
+notebook_append_locpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook)
+{
+	notebook_append_awardpage (scorewindow, awardsnotebook, "loctreeview", "GRID", "scrolledwindow6");
 }
 
 GtkWidget *
@@ -500,6 +325,7 @@ create_scorewindow (void)
 	GtkTreeViewColumn *column;
 	GtkTreeIter iter;
 	gchar *temp;
+	gint awardscount, i;
 
 	scorewindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_accept_focus (GTK_WINDOW(scorewindow), FALSE);
@@ -763,8 +589,10 @@ create_scorewindow (void)
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_SUBMM] - 48);
 
-	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+	awardscount = NB_AWARDS;
+
+	for (i=0; i<awardscount; i++)
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 
 	gtk_tree_selection_set_mode
 		(gtk_tree_view_get_selection (GTK_TREE_VIEW (countrytreeview)),
@@ -781,6 +609,18 @@ create_scorewindow (void)
 	if (preferences.awardswac == 1)
 		notebook_append_wacpage (scorewindow, awardsnotebook);
 
+	if (preferences.awardswas == 1)
+		notebook_append_waspage (scorewindow, awardsnotebook);
+
+	if (preferences.awardswaz == 1)
+		notebook_append_wazpage (scorewindow, awardsnotebook);
+
+	if (preferences.awardsiota == 1)
+		notebook_append_iotapage (scorewindow, awardsnotebook);
+
+	if (preferences.awardsloc == 1)
+		notebook_append_locpage (scorewindow, awardsnotebook);
+
 	GLADE_HOOKUP_OBJECT (scorewindow, dxccframe, "dxccframe");
 	GLADE_HOOKUP_OBJECT (scorewindow, dxcclabel1, "dxcclabel1");
 	GLADE_HOOKUP_OBJECT (scorewindow, contlabel, "contlabel");
@@ -813,6 +653,14 @@ on_scoring_activate (GtkAction *action, gpointer user_data)
 		update_dxccscoring ();
 		if (preferences.awardswac == 1)
 			update_wacscoring ();
+		if (preferences.awardswas == 1)
+			update_wasscoring ();
+		if (preferences.awardswaz == 1)
+			update_wazscoring ();
+		if (preferences.awardsiota == 1)
+			update_iotascoring ();
+		if (preferences.awardsloc == 1)
+			update_locscoring ();
 		gtk_widget_show (scorewindow);
 		gdk_window_move_resize (scorewindow->window,
 			preferences.scorex, preferences.scorey, preferences.scorewidth, preferences.scoreheight);
