@@ -22,6 +22,15 @@
 
 /* gui_scorewindow.h */
 
+#ifndef GUI_SCOREWINDOW_H
+#define GUI_SCOREWINDOW_H
+
 void on_scoring_activate (GtkAction *action, gpointer user_data);
 GtkWidget *create_scorewindow (void);
 void notebook_append_wacpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook);
+void notebook_append_waspage (GtkWidget *scorewindow, GtkWidget *awardsnotebook);
+void notebook_append_wazpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook);
+void notebook_append_iotapage (GtkWidget *scorewindow, GtkWidget *awardsnotebook);
+void notebook_append_locpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook);
+
+#endif	/* GUI_SCOREWINDOW_H */
