@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 #include <gtk/gtk.h>
 #include <math.h>
@@ -28,6 +31,8 @@
 #include "utils.h"
 #include "support.h"
 #include "main.h"
+#include "gui_warningdialog.h"
+
 #include "data/pixmaps/s0.xpm"
 #include "data/pixmaps/s1.xpm"
 #include "data/pixmaps/s2.xpm"
@@ -66,7 +71,7 @@ typeLevel S[] = {
 	{NULL, NULL, NULL}
 };
 extern preferencestype preferences;
-extern statetype state;
+extern programstatetype programstate;
 extern GtkWidget *mainwindow;
 gint svalue[10];
 gint hamlibtimer = -1;
@@ -272,6 +277,15 @@ hamlib_error (gint code)
 					 rigerror (code));
 	update_statusbar (message);
 	g_free (message);
+
+	if (code == -1)
+	{
+		warningdialog ("xlog - hamlib",
+		_("There was an error while communicating with your rig, "
+		"hamlib has stopped"), "gtk-dialog-warning");
+		stop_hamlib();
+		preferences.hamlib = 0;
+	}
 }
 
 /* get power level from the rig */
@@ -288,7 +302,7 @@ get_powerlevel (void)
 		retcode =	rig_get_level (myrig, RIG_VFO_CURR, RIG_LEVEL_RFPOWER, &val);
 		if (retcode == RIG_OK)
 		{
-			status = rig_power2mW (myrig, &state.rigpower, val.f, state.rigfrequency, state.rigmode);
+			status = rig_power2mW (myrig, &programstate.rigpower, val.f, programstate.rigfrequency, programstate.rigmode);
 		}
 		else if (retcode != -RIG_ENAVAIL)
 			hamlib_error (retcode);
@@ -306,7 +320,7 @@ get_mode (void)
 	retcode = rig_get_mode (myrig, RIG_VFO_CURR, &rmode, &width);
 	if (retcode == RIG_OK)
 	{
-		state.rigmode = rmode;
+		programstate.rigmode = rmode;
 	}
 	else if (retcode != -RIG_ENAVAIL)
 		hamlib_error (retcode);
@@ -325,7 +339,7 @@ get_frequency (void)
 	retcode = rig_get_freq (myrig, RIG_VFO_CURR, &freq);
 	if (retcode == RIG_OK)
 	{
-		state.rigfrequency = freq;
+		programstate.rigfrequency = freq;
 		if ((preferences.hamlib == 2) || (preferences.hamlib == 4))
 		{
 			digits = convert_frequency ();
@@ -348,7 +362,7 @@ set_frequency (long long freq)
 	if (preferences.polltime == 0)
 	{
 		rig_set_freq (myrig, RIG_VFO_CURR, freq);
-		state.rigfrequency = freq;
+		programstate.rigfrequency = freq;
 	}
 	else
 		setfreq = freq;
@@ -365,9 +379,9 @@ get_ptt (void)
 	if (retcode == RIG_OK)
 	{
 		if (ptt == RIG_PTT_OFF)
-			state.tx = FALSE;
+			programstate.tx = FALSE;
 		else
-			state.tx = TRUE;
+			programstate.tx = TRUE;
 	}
 	else if (retcode != -RIG_ENAVAIL)
 		hamlib_error (retcode);
@@ -377,37 +391,34 @@ get_ptt (void)
 void
 get_smeter (void)
 {
-	gint retcode, strength, spoint, i, smax = 1;
+	gint retcode, strength, spoint, i, smax = 0;
 
 	retcode = rig_get_strength (myrig, RIG_VFO_CURR, &strength);
 	if (retcode == RIG_OK)
 	{
 		if (strength >= 0)
 			spoint = 9;
-		else if (strength < -60)
-			spoint = 0;
 		else
-			spoint = (gint) ceil ((strength + 60) / 6);
-		svalue[state.scounter] = spoint;
-		state.scounter++;
-		if (state.scounter == 10)
-			state.scounter = 0;
+			spoint = (gint) floor ((strength + 54) / 6);
 
-		/* find maximum of s-meter during last 3 seconds */
-		for (i = 0; i < 10; i++)
+		svalue[programstate.scounter] = spoint;
+		programstate.scounter++;
+		if (programstate.scounter == 3)
+			programstate.scounter = 0;
+
+		/* find maximum of s-meter during last 3 measurements */
+		for (i = 0; i < 3; i++)
 			if (svalue[i] > smax)
 				smax = svalue[i];
 
 		if ((preferences.hamlib == 3) || (preferences.hamlib == 4))
 			draw_smeter (smax);
 
-		if (smax == 0)
-			smax = 1;
-		if ((state.rigmode == RIG_MODE_CW)
-				|| (state.rigmode == RIG_MODE_RTTY))
-			state.rigrst = g_strdup_printf ("5%d9", smax);
+		if ((programstate.rigmode == RIG_MODE_CW)
+				|| (programstate.rigmode == RIG_MODE_RTTY))
+			programstate.rigrst = g_strdup_printf ("5%d9", smax);
 		else
-			state.rigrst = g_strdup_printf ("5%d", smax);
+			programstate.rigrst = g_strdup_printf ("5%d", smax);
 	}
 	else if (retcode != -RIG_ENAVAIL)
 		hamlib_error (retcode);
@@ -420,7 +431,7 @@ get_riginfo (void)
 	get_frequency ();
 	get_mode ();
 	get_ptt ();
-	if (!state.tx)
+	if (!programstate.tx)
 		get_smeter ();
 	else if ((preferences.hamlib == 3) || (preferences.hamlib == 4))
 		draw_smeter (0);
@@ -433,45 +444,45 @@ poll_riginfo (void)
 {
 	if (setfreq != 0)
 	{
-		if (state.hlcounter == 0)
-			state.hlcounter++;
+		if (programstate.hlcounter == 0)
+			programstate.hlcounter++;
 		rig_set_freq (myrig, RIG_VFO_CURR, setfreq);
-		state.rigfrequency = setfreq;
+		programstate.rigfrequency = setfreq;
 		setfreq = 0;
 		return 1;
 	}
 
-	if (state.hlcounter == 0)
+	if (programstate.hlcounter == 0)
 	{
-		state.hlcounter++;
+		programstate.hlcounter++;
 		get_frequency ();
 		return 1;
 	}
-	if (state.hlcounter == 1)
+	if (programstate.hlcounter == 1)
 	{
-		state.hlcounter++;
+		programstate.hlcounter++;
 		get_mode ();
 		return 1;
 	}
-	if (state.hlcounter == 2)
+	if (programstate.hlcounter == 2)
 	{
-		state.hlcounter++;
+		programstate.hlcounter++;
 		get_ptt ();
 		return 1;
 	}
-	if (state.hlcounter == 3)
+	if (programstate.hlcounter == 3)
 	{
-		state.hlcounter++;
-		if (!state.tx)
+		programstate.hlcounter++;
+		if (!programstate.tx)
 			get_smeter ();
 		else if ((preferences.hamlib == 3)
 			 || (preferences.hamlib == 4))
 			draw_smeter (0);
 		return 1;
 	}
-	if (state.hlcounter == 4)
+	if (programstate.hlcounter == 4)
 	{
-		state.hlcounter = 0;
+		programstate.hlcounter = 0;
 		get_powerlevel ();
 		return 1;
 	}
@@ -602,9 +613,9 @@ GString *convert_frequency (void)
 	GString *digits = g_string_new ("");
 
 	if (preferences.round == 0)
-		g_string_printf (digits, "%Ld", state.rigfrequency);
+		g_string_printf (digits, "%Ld", programstate.rigfrequency);
 	else
-		g_string_printf (digits, "%Ld", (long long) rint (state.rigfrequency /
+		g_string_printf (digits, "%Ld", (long long) rint (programstate.rigfrequency /
 			pow (10, preferences.round)));
 	g_string_insert_c (digits, (digits->len) - 6 + preferences.round, '.');
 	g_strstrip (digits->str);
