@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * log.c - assorted utilities for maintaining the logs
@@ -39,7 +42,7 @@
 #include "main.h"
 
 extern GtkWidget *mainnotebook;
-extern statetype state;
+extern programstatetype programstate;
 extern preferencestype preferences;
 extern gchar **qso;
 
@@ -105,7 +108,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 	gint i;
 	GtkTreePath *path;
 
-	state.qsos++;
+	programstate.qsos++;
 	logw->qsos++;
 	q[NR] = g_strdup_printf ("%d", logw->qsos);
 
@@ -123,7 +126,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[DATE], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			date = g_convert_with_fallback(q[DATE], strlen(q[DATE]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!date) date = g_strdup ("");
 		}
@@ -163,7 +166,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[NAME], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			name = g_convert_with_fallback(q[NAME], strlen(q[NAME]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!name) name = g_strdup ("");
 		}
@@ -180,7 +183,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[QTH], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			qth = g_convert_with_fallback(q[QTH], strlen(q[QTH]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!qth) qth = g_strdup ("");
 		}
@@ -200,7 +203,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[U1], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			u1 = g_convert_with_fallback(q[U1], strlen(q[U1]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!u1) u1 = g_strdup ("");
 		}
@@ -217,7 +220,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[U2], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			u2 = g_convert_with_fallback(q[U2], strlen(q[U2]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!u2) u2 = g_strdup ("");
 		}
@@ -234,7 +237,7 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[REMARKS], error->message);
 			g_error_free (error);
-			state.utf8error = TRUE;
+			programstate.utf8error = TRUE;
 			remarks = g_convert_with_fallback(q[REMARKS], strlen(q[REMARKS]), "UTF-8", "ISO-8859-1", ".", NULL, NULL, NULL);
 			if (!remarks) remarks = g_strdup ("");
 		}
