@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <locale.h>
+#include <ctype.h>
 #ifndef __USE_XOPEN
 #define __USE_XOPEN
 #endif
@@ -60,6 +61,7 @@ static const gint cabrillo_fields[] =
 static const gint cabrillo_widths[] = { 5, 2, 10, 4, 10, 13, 10 };
 static const gint cabrillo_ss_widths[] = { 5, 2, 10, 4, 13, 10, 13 };
 static const gint cabrillo_na_widths[] = { 5, 2, 10, 4, 20, 10, 21 };
+static const gint cabrillo_iota_widths[] = { 5, 2, 10, 4, 15, 13, 15 };
 static const gint cabrillo_field_nr = 7;
 
 static gint cabrillo_open (LOGDB *);
@@ -87,7 +89,7 @@ gint
 cabrillo_open (LOGDB * handle)
 {
 	FILE *fp;
-	const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST, REMARKS};
+	static const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST, AWARDS, REMARKS};
 
 	fp = fopen (handle->path, "r");
 	if (!fp)
@@ -246,7 +248,8 @@ enum cbr_contest_type
 {
 	CBR_OTHER,
 	CBR_SWEEPSTAKES,
-	CBR_NA
+	CBR_NA,
+	CBR_IOTA
 };
 
 gint
@@ -262,6 +265,7 @@ cabrillo_qso_foreach (LOGDB * handle,
 	gint sent_call_len = 14;
 	struct tm tm_cab;
 	gboolean phone;
+	gint awards_was = 0;
 
 	while (!feof (fp))
 	{
@@ -283,12 +287,24 @@ cabrillo_qso_foreach (LOGDB * handle,
 					contest_type = CBR_NA;
 					widths = cabrillo_na_widths;
 					sent_call_len = 11;
+					awards_was = 1;
 				}
 				else if (!strncmp (buffer + 9, "ARRL-SS", 7))
 				{
 					contest_type = CBR_SWEEPSTAKES;
 					widths = cabrillo_ss_widths;
 					sent_call_len = 11;
+					awards_was = 1;
+				}
+				else if (!strncmp (buffer + 9, "ARRL", 4))
+				{
+					awards_was = 1;
+				}
+				else if (!strncmp (buffer + 9, "RSGB-IOTA", 9))
+				{
+					contest_type = CBR_IOTA;
+					widths = cabrillo_iota_widths;
+					sent_call_len = 14;
 				}
 			}
 			else if (!strncmp (buffer, "END-OF-LOG:", 11))
@@ -310,9 +326,33 @@ cabrillo_qso_foreach (LOGDB * handle,
 			end = field + widths[i];
 			*end = '\0';
 
-			/* check the different mode strings and store mode */
-			if (i == 1)
+			switch (i)
 			{
+			case 0:
+				if (!strchr(field, 'G') && (
+					!strncmp(field, " 1", 2) ||
+					!strncmp(field, " 3", 2) ||
+					!strncmp(field, " 7", 2) ||
+					(!strncmp(field, "14", 2) && field[2]!='4') ||
+					!strncmp(field, "21", 2) ||
+					!strncmp(field, "28", 2)))
+				{
+					gint khz = atoi(field);
+					if (khz%1000 == 0)
+						q[cabrillo_fields[i]] =
+							g_strdup_printf ("%d", khz/1000);
+					else
+						q[cabrillo_fields[i]] =
+							g_strdup_printf ("%d.%d", khz/1000, khz%1000);
+				}
+				else
+				{
+					q[cabrillo_fields[i]] = g_strdup (g_strstrip (field));
+				}
+				break;
+
+			case 1:
+				/* check the different mode strings and store mode */
 				if (!strcmp (field, "PH"))
 				{
 					phone = TRUE;
@@ -323,11 +363,10 @@ cabrillo_qso_foreach (LOGDB * handle,
 				else
 					strcpy (buf, field);
 				q[cabrillo_fields[i]] = g_strdup (buf);
-			}
+				break;
 
-			/* reformat date 2007-01-23 -> 23 Jan 2007 */
-			else if (i == 2)
-			{
+			case 2:
+				/* reformat date 2007-01-23 -> 23 Jan 2007 */
 				res = strptime (field, "%Y-%m-%d", &tm_cab);
 				if (res != NULL)
 				{
@@ -338,10 +377,15 @@ cabrillo_qso_foreach (LOGDB * handle,
 				else
 					strcpy (buf, field);
 				q[cabrillo_fields[i]] = g_strdup (buf);
-			}
+				break;
 
-			else if (i == 4 || i == 6)
-			{/* TODO: add prepending zero's if serial */
+			case 4:
+			case 6:
+				/* cut IOTA ref */
+				if (contest_type == CBR_IOTA)
+					field[8] = '\0';
+
+				/* TODO: add prepending zero's if serial */
 				if (phone)
 				{
 					strcpy (buf, field + 2);
@@ -354,18 +398,37 @@ cabrillo_qso_foreach (LOGDB * handle,
 					g_strstrip (buf);
 					field[3] = '\0';
 				}
+
 				q[cabrillo_fields[i]] =
 					g_strdup_printf ("%s%s", field, buf);
+
+				if (i == 6 && contest_type == CBR_IOTA &&
+						strcmp(field+9, "------"))
+				{
+					field[9+6] = '\0';
+					g_strstrip (field+9);
+					q[AWARDS] = g_strdup_printf ("IOTA-%s", field+9);
+				}
+				else if (i == 6 && awards_was && isupper(field[4]) &&
+						strcmp(field+4, "DX"))
+				{
+					g_strstrip (field+4);
+					q[AWARDS] = g_strdup_printf ("WAS-%s", field+4);
+				}
+				/* TODO: WAZ for CONTEST:CQ-WW* ? */
+
 				/* add the remark field if present */
 				if ((i == 6) && (strlen(programstate.importremark) > 0))
 				{
 					q[cabrillo_fields[i + 1]] =
 						g_strdup (programstate.importremark);
 				}
+				break;
+
+			default:
+				q[cabrillo_fields[i]] = g_strdup (g_strstrip (field));
 			}
 
-			else
-				q[cabrillo_fields[i]] = g_strdup (g_strstrip (field));
 			field = end + 1;
 		}
 
