@@ -150,8 +150,6 @@ static void
 setdefaultstate (void)
 {
 	programstate.qsos = 0;
-	/* the default ham lives in the gulf of guinea */
-	programstate.mylocation = g_strdup ("0.0N0.0E");
 	programstate.controlkey = FALSE;
 	programstate.rigfrequency = 0;
 	programstate.rigmode = 0;
@@ -163,8 +161,6 @@ setdefaultstate (void)
 	programstate.statustimer = FALSE;
 	programstate.shmid = -1;
 	programstate.logwindows = 0;
-	programstate.mylocation = setlocation (preferences.latitude, preferences.NS,
-					preferences.longitude, preferences.EW);
 	programstate.searchstr = g_strdup("");
 	programstate.importremark = g_strdup("");
 	programstate.dupecheck = 0;
@@ -196,6 +192,7 @@ main (int argc, char *argv[])
 	logtype *logwindow = NULL;
 	LOGDB *lp = NULL;
 	gboolean hamlibresult = FALSE;
+	GtkTreePath *path;
 
 	parsecommandline (argc, argv);
 
@@ -307,6 +304,14 @@ main (int argc, char *argv[])
 			log_file_qso_foreach (lp, fillin_list, logwindow);
 			log_file_close (lp);
 			logwindow->filename = g_strdup (xlogfile);
+			if (logwindow->qsos > 1000)
+			{
+				path = gtk_tree_path_new_from_string ("0");
+				gtk_tree_view_scroll_to_cell
+					(GTK_TREE_VIEW (logwindow->treeview), path, NULL, TRUE, 0.5, 0.0);
+				gtk_tree_path_free (path);
+
+			}
 			logwindowlist = g_list_append (logwindowlist, logwindow);
 			/* backup */
 			if (preferences.backup == 1)
@@ -490,6 +495,14 @@ main (int argc, char *argv[])
 		update_dxccscoring ();
 		if (preferences.awardswac == 1)
 			update_wacscoring ();
+		if (preferences.awardswas == 1)
+			update_wasscoring ();
+		if (preferences.awardswaz == 1)
+			update_wazscoring ();
+		if (preferences.awardsiota == 1)
+			update_iotascoring ();
+		if (preferences.awardsloc == 1)
+			update_locscoring ();
 		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuitem), TRUE);
 		gtk_widget_show (scorewindow);
 		gdk_window_move_resize (scorewindow->window, preferences.scorex,
