@@ -127,6 +127,10 @@ static gint make_default_preferences (void)
 	preferences.scoringbands = g_strdup ("01101111111000000000000000000");
 	preferences.distqrb = 0;
 	preferences.awardswac = 0;
+	preferences.awardswas = 0;
+	preferences.awardswaz = 0;
+	preferences.awardsiota = 0;
+	preferences.awardsloc = 0;
 	return 0;
 }
 
@@ -648,6 +652,30 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.awardswac = atoi ((const char *)key);
 			free (key);
 		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"awardswas")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.awardswas = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"awardswaz")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.awardswaz = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"awardsiota")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.awardsiota = atoi ((const char *)key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"awardsloc")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.awardsloc = atoi ((const char *)key);
+			free (key);
+		}
 
 	cur = cur->next;
 	}
@@ -1171,6 +1199,30 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "awardswas"))
+		{
+			key = g_strdup_printf ("%d", preferences.awardswas);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "awardswaz"))
+		{
+			key = g_strdup_printf ("%d", preferences.awardswaz);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "awardsiota"))
+		{
+			key = g_strdup_printf ("%d", preferences.awardsiota);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "awardsloc"))
+		{
+			key = g_strdup_printf ("%d", preferences.awardsloc);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
 	}
 }
 
@@ -1268,6 +1320,10 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoringbands", (const xmlChar *)"01101111111000000000000000000");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"distqrb", (const xmlChar *)"0");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardswac", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardswas", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardswaz", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardsiota", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardsloc", (const xmlChar *)"0");
 	g_free (homedir);
 }
 
