@@ -1,26 +1,24 @@
-/* 
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+/*
 
-   Convert a string representation of time to a time value.
-   Copyright (C) 1996, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
-   This file is part of the GNU C Library.
-   Contributed by Ulrich Drepper <drepper@cygnus.com>, 1996.
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
 
-   The GNU C Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   This file is part of xlog.
 
-   The GNU C Library is distributed in the hope that it will be useful,
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* XXX This version of the implementation is not really complete.
    Some of the fields cannot add information alone.  But if seeing
