@@ -70,28 +70,6 @@ extern void *shareCall;
 extern GList *logwindowlist;
 extern GtkUIManager *ui_manager;
 
-/* calculate location string from latitude and longitude information,
- * returned value has to be freed */
-gchar *
-setlocation (gdouble lat, gint NS, gdouble lon, gint EW)
-{
-	gchar *location, *ns, *ew;
-
-	if (NS == 1)
-		ns = g_strdup (_("N"));
-	else
-		ns = g_strdup (_("S"));
-	if (EW == 1)
-		ew = g_strdup (_("E"));
-	else
-		ew = g_strdup (_("W"));
-	location = g_strdup_printf ("%3.2f%s%3.2f%s", lat, ns, lon, ew);
-	g_free (ns);
-	g_free (ew);
-
-	return (location);
-}
-
 /* update the menu items of an optionmenu */
 void
 makebandoptionmenu (gchar *bands)
@@ -215,7 +193,6 @@ update_statusbar (gchar * string)
 static void
 freestate (void)
 {
-	g_free (programstate.mylocation);
 	g_free (programstate.rigrst);
 	g_free (programstate.searchstr);
 }
@@ -687,7 +664,7 @@ my_strreplace(const char *str, const char *delimiter, const char *replacement)
 
 /* check if the awards entry contains a valid awards string */
 gchar *
-valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont)
+valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont, guint *iota)
 {
 	gchar **s = g_strsplit (a, ",", -1);
 	gchar *p = NULL, *dup = NULL;
@@ -696,6 +673,7 @@ valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont)
 	*st = 99;
 	*zone = 99;
 	*cont = 99;
+	*iota = NOT_AN_IOTA;
 	for (;;)
 	{
 		if (s[i] == NULL) break;
@@ -708,8 +686,10 @@ valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont)
 				*zone = atoi (p + 1);
 			else if (!g_ascii_strncasecmp(s[i], "WAC", 3))
 				*cont = cont_to_enum (p + 1);
-			else if (!g_ascii_strncasecmp(s[i], "WAS", 4))
+			else if (!g_ascii_strncasecmp(s[i], "WAS", 3))
 				*st = state_to_enum (p + 1);
+			else if (!g_ascii_strncasecmp(s[i], "IOTA", 4))
+				*iota = iota_to_num (p + 1);
 		}
 		i++;
 	}
