@@ -24,7 +24,6 @@
  * utils.h
  */
 
-gchar *setlocation (gdouble lat, gint NS, gdouble lon, gint EW);
 void makebandoptionmenu (gchar *bands);
 void makemodeoptionmenu (gchar *modes);
 void deletespaces (gchar ** split);
@@ -41,5 +40,5 @@ gint autosave (void);
 void set_qsoframe (gpointer arg);
 gboolean fileexist (gchar * path);
 gchar *my_strreplace(const char *str, const char *delimiter, const char *replacement);
-gchar *valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont);
+gchar *valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont, guint *iota);
 gboolean qslreceived(gchar *in);
