@@ -24,5 +24,5 @@
  * wwl.h
  */
 
-gint wwl (gchar * my, gchar * dx, gint *dist, gint *bearing);
+gint locatordistance (gchar *my, gchar *dx, gint *dist, gint *bearing);
 void updatelocatorframe (gchar * locator);
